/// <amd-module name="@cxl/ui/a11y.js" />
import { Observable } from './rx.js';
import type { Component } from './component.js';
type AriaProperties = {
    atomic: string;
    autocomplete: string;
    busy: string;
    checked: string;
    controls: string;
    current: string;
    describedby: string;
    details: string;
    disabled: string;
    dropeffect: string;
    errormessage: string;
    expanded: string;
    flowto: string;
    grabbed: string;
    haspopup: string;
    hidden: string;
    invalid: string;
    keyshortcuts: string;
    label: string;
    labelledby: string;
    level: string;
    live: string;
    orientation: string;
    owns: string;
    placeholder: string;
    pressed: string;
    readonly: string;
    required: string;
    selected: string;
    sort: string;
    valuemax: string;
    valuemin: string;
    valuenow: string;
    valuetext: string;
    modal: string;
    multiline: string;
    multiselectable: string;
    relevant: string;
    roledescription: string;
};
type AriaProperty = keyof AriaProperties;
export type AriaAttributeName = `aria-${AriaProperty}`;
/**
 * Sets an ARIA property on a component.
 * @param prop The ARIA property name (e.g., "checked", "modal").
 * @param value The value to set for the property.
 * @returns An Observable that sets the attribute on the component.
 */
export declare function aria<T extends Component>(prop: AriaProperty, value: string): (ctx: T) => Observable<unknown, "none">;
/**
 * Sets the value of an ARIA property on an HTML element.
 * Handles boolean and undefined values for specific properties.
 * @param host The target element.
 * @param prop The ARIA property name.
 * @returns An Observable that sets the attribute on the element.
 */
export declare function ariaValue(host: Element, prop: AriaProperty): import("@cxl/ui/rx.js").Operator<string | number | boolean, string | number | boolean>;
/**
 * Specialized function to set the "aria-checked" state of an element
 * Handles boolean and undefined values appropriately for mixed states
 */
export declare function ariaChecked(host: Element): import("@cxl/ui/rx.js").Operator<boolean | undefined, boolean | undefined>;
/**
 * Function to set the ARIA role of a component
 */
export declare function role<T extends Component>(roleName: string): (ctx: T) => Observable<unknown, "none">;
export declare function ariaDescribed(target: Element, by: Element): Observable<string, "none">;
/**
 * Sets the aria-label on a target element based on changes to a source element's attributes.
 * Considers inline content ("title" or "aria-label") and referenced elements ("aria-labelledby").
 * @param source The source element to monitor for attribute changes.
 * @param target The target element to set the aria-label on.
 * @param text An optional Observable that provides additional text for the aria-label.
 * @returns An Observable that manages the aria-label updates.
 */
export declare function ariaLabelOrDefault(source: HTMLElement, target: HTMLElement, text?: Observable<string>): Observable<string, "none">;
/**
 * Apply aria label only if not specified
 */
export declare function ariaLabel(text: Observable<string>): (el: HTMLElement) => Observable<string, "none">;
export declare function getAriaId(el: Element): Observable<string, "none">;
export {};
