/// <amd-module name="@cxl/ui/alert.js" />
import { Component } from './component.js';
import { SurfaceColorValue } from './theme.js';
/**
 * The Alert component serves as a visual element for displaying important messages to users.
 * These messages are typically time-sensitive and require immediate attention.
 * It can contain text, icons, and buttons for the user to respond.
 *
 * @example
 * <cxl-alert><cxl-icon alt="" name="warning"></cxl-icon> Default Alert</cxl-alert><br />
 * <cxl-alert dense color="error" outline><cxl-icon alt="" name="error"></cxl-icon> Error Message!</cxl-alert>
 */
export declare class Alert extends Component {
    /**
     * When set to true, the alert component becomes more compact, making it suitable for situations where space is limited.
     */
    dense: boolean;
    /**
     * Adds an outline style to the alert, emphasizing its boundaries.
     * @example
     * <cxl-alert color="error" outline><cxl-icon alt="" name="error"></cxl-icon> Error Message!</cxl-alert>
     */
    outline: boolean;
    /**
     * Determines the background color of the alert. You can choose from predefined colors such as “success,” “warning,” or “error.”
     * @example
     * <cxl-alert color="success">Success!</cxl-alert>
     * <cxl-alert color="warning">Warning!</cxl-alert>
     */
    color?: SurfaceColorValue;
}
