/// <amd-module name="@cxl/ui/autocomplete-base.js" />
import { TextInputBase } from './input.js';
import { SelectMenuBase, SelectOption } from './select.js';
import { Option } from './option.js';
import type { InputBase } from './input-base.js';
/**
 * @beta
 */
export declare class AutocompleteInput extends TextInputBase {
    /**  A string representing the current value of the input field. */
    value: unknown;
    selectedOption?: Option;
    inputEl: HTMLInputElement;
}
/**
 * @beta
 */
export declare abstract class AutocompleteBase extends SelectMenuBase {
    protected readonly acceptKeys: string[];
    /**
     * A set of available options for the autocomplete dropdown
     */
    readonly options: Set<Option>;
    /**
     * The currently selected option, reflected in the input value
     */
    readonly selected?: Option;
    /**
     * The component used to render individual options in the dropdown
     */
    optionView: typeof SelectOption;
    /**
     * Internal reference to the empty slot element
     */
    protected emptySlot: HTMLSlotElement;
    /**
     * Abstract method that needs to be implemented by subclasses to handle search logic
     * @param term The search term entered by the user
     */
    protected abstract handleSearch(term: string): void;
    /**
     * Sets the selected option and updates the value and visibility of the autocomplete
     * @param option The option to set as selected
     */
    protected setSelected(option?: Option): void;
    /**
     * Sets the value of the input element associated with the autocomplete
     * @param input The input element to update
     * @param value The value to set
     */
    protected setInputValue(input: InputBase, value: string | undefined): void;
    /**
     * Sets the focused option and scrolls it into view if necessary
     * @param option The option to set as focused
     */
    setFocusedOption(option?: Option): void;
}
