/// <amd-module name="@cxl/ui/badge.js" />
import { Component } from './component.js';
import { SurfaceColorValue } from './theme.js';
import { Size } from './core.js';
/**
 * The Badge component offers a versatile way to display small informational indicators alongside other UI elements.
 * It's commonly used to highlight status, notifications, or counts.
 *
 * @example
 * <cxl-avatar size="1" alt="avatar"></cxl-avatar><cxl-badge top overlap>5</cxl-badge>
 */
export declare class Badge extends Component {
    /**
     * Controls the size of the badge.
     * @example
     * <cxl-avatar text="GB" alt="avatar"></cxl-avatar><cxl-badge color="success" size="-1" overlap></cxl-badge>
     */
    size: Size;
    /**
     * Sets the background color of the badge
     *
     * @example
     * <cxl-badge color="secondary">1</cxl-badge>
     * <cxl-badge color="success">2</cxl-badge>
     * <cxl-badge color="error">3</cxl-badge>
     * <cxl-badge color="warning">4</cxl-badge>
     */
    color?: SurfaceColorValue;
    /**
     * When set to true, positions the badge slightly overlapping the element it's badging.
     * This is useful for scenarios like badging avatars or buttons.
     *
     * @example
     * <cxl-avatar alt=""></cxl-avatar><cxl-badge color="secondary" overlap>5</cxl-badge>
     * <cxl-button color="primary"><span>Badge<cxl-badge top color="warning" size="small"></cxl-badge></span></cxl-button>
     */
    overlap: boolean;
    /**
     * When set to true, positions the badge at the top of the element it's badging.
     * This can be useful for specific use cases where the default bottom positioning might not be ideal.
     */
    top: boolean;
}
