/// <amd-module name="@cxl/ui/calendar-month.js" />
import { Component } from './component.js';
import { Grid } from './layout.js';
import { CustomInputBase } from './input-base.js';
import { CalendarEventData } from './calendar-event.js';
import type { DateInformation } from './calendar-date.js';
interface CalendarCellData {
    element: CalendarCell;
    index: number;
    overflow: number;
    date: Date;
}
export declare class CalendarCell extends Component {
    overflow: number;
    date?: DateInformation;
    onshowmore?: (ev: CustomEvent<DateInformation>) => void;
}
/**
 * Input component for selecting a date within a calendar month view.
 *
 * @beta
 * @demo
 * <cxl-calendar-month-input month="1984-08" value="1984-08-06">
 * </cxl-calendar-month>
 */
export declare class CalendarMonthInput extends CustomInputBase {
    /** The currently displayed month. */
    month: Date;
    /**  The selected date within the displayed month */
    value: Date | undefined;
    protected grid?: Grid;
    /** Stores a collection of calendar cells for rendering */
    cells: Record<string, CalendarCellData>;
    /** The start date of the displayed month, calculated internally */
    readonly startDate?: Date;
    protected onClickDate(date: DateInformation): void;
    /** Focuses the component's date element. */
    focus(): void;
}
/**
 * Renders a calendar month view that allows users to select a date and displays associated events.
 *
 * @beta
 * @demo
 * <cxl-calendar-month month="1984-08">
 *   <cxl-calendar-event start="1984-08-06" end="1984-08-06">Birthday</cxl-calendar-event>
 * </cxl-calendar-month>
 */
export declare class CalendarMonth extends CalendarMonthInput {
    /** An array of events to display on the calendar. */
    events: CalendarEventData[];
    protected onClickDate(date: DateInformation): void;
}
export {};
