/// <amd-module name="@cxl/ui/carousel.js" />
import { Component, Span } from './component.js';
declare module './registable.js' {
    interface RegistableMap {
        slide: Component;
    }
}
/**
 * Represents a single slide element within a Carousel component.
 *
 * @see Carousel
 */
export declare class Slide extends Component {
}
declare const SlideAnimation: {
    default(host: Carousel, el: Span): void;
    continuous(host: Carousel, el: Span, prev: number): void;
};
/**
 * Carousel with automatic or manual navigation for displaying a sequence of slides.
 *
 * @demo
 * <cxl-carousel delay="2000" type="continuous">
 *   <cxl-slide><cxl-t h5>Slide 1</cxl-t></cxl-slide>
 *   <cxl-slide><cxl-t h5>Slide 2</cxl-t></cxl-slide>
 *   <cxl-slide><cxl-t h5>Slide 3</cxl-t></cxl-slide>
 * </cxl-carousel>
 */
export declare class Carousel extends Component {
    /**
     * Delay in milliseconds for automatic rotation. Set to 0 to disable.
     * This attribute will be ignored if the "prefers-reduced-motion" browser
     * setting is enabled.
     */
    delay: number;
    /**
     * Defines the speed of the animation in milliseconds for slide transitions. Defaults to 500.
     */
    speed: number;
    /**
     * Determines the type of animation used for slide transitions.
     */
    type: keyof typeof SlideAnimation;
    /**
     * Represents the index of the currently displayed slide.
     * Updated automatically during transitions or manually through user interaction.
     */
    index: number;
    /**
     * Determines how many slides to step through at a time. Defaults to 1.
     */
    step: number;
    /**
     * Property that holds a collection of registered slide components.
     */
    slides: Set<Slide>;
}
/**
 * This component provides pagination controls for Carousel component,
 * allowing users to navigate between slides manually.
 *
 * @demo
 * <cxl-carousel>
 *   <cxl-slide><cxl-c pad16><cxl-t h5>Slide 1</cxl-t></cxl-c></cxl-slide>
 *   <cxl-slide><cxl-c pad16><cxl-t h5>Slide 2</cxl-t></cxl-c></cxl-slide>
 *   <cxl-slide><cxl-c pad16><cxl-t h5>Slide 3</cxl-t></cxl-c></cxl-slide>
 *   <cxl-carousel-pagination></cxl-carousel-pagination>
 * </cxl-carousel>
 */
export declare class CarouselPagination extends Component {
}
/**
 * This component provides the navigation controls for Carousel component,
 * for advancing or reversing through slides.
 *
 * @demo
 * <cxl-carousel style="text-align:center;height: 60px">
 *   <cxl-slide><cxl-t h5>Slide 1</cxl-t></cxl-slide>
 *   <cxl-slide><cxl-t h5>Slide 2</cxl-t></cxl-slide>
 *   <cxl-slide><cxl-t h5>Slide 3</cxl-t></cxl-slide>
 *   <cxl-carousel-navigation></cxl-carousel-navigation>
 * </cxl-carousel>
 */
export declare class CarouselNavigation extends Component {
}
export {};
