/// <amd-module name="@cxl/ui/chip-group.js" />
import { Component } from './component.js';
import type { Option } from './option.js';
/**
 * This component represents a group of selectable chips, similar to a toggle button group.
 * It allows users to choose one option at a time from a set of choices displayed as chips.
 *
 * @beta
 * @demo
 * <cxl-chip-group aria-label="Chip Group">
 *   <cxl-chip-selectable value="1" removable>Chip 1</cxl-chip-selectable>
 *   <cxl-chip-selectable value="2" removable>Chip 2</cxl-chip-selectable>
 * </cxl-chip-group>
 */
export declare class ChipGroup extends Component {
    /**
     * The currently selected value of the chip group. Can be any type.
     */
    value: unknown;
    /**
     * The currently selected chip within the chip group.
     */
    selected: Option | undefined;
    /**
     * A set containing all the options available in the chip group.
     */
    readonly options: Set<Option>;
}
