/// <amd-module name="@cxl/ui/core.js" />
import { AttributeEvent, Component, ComponentAttributeName } from './component.js';
import { Observable, Operator } from './rx.js';
import { BreakpointKey, StyleDefinition } from './css.js';
import { CustomEventMap } from './dom.js';
import './template.js';
import { SurfaceColorValue, Styles } from './theme.js';
declare module './rx.js' {
    interface Observable<T> {
        is(equalTo: T): Observable<boolean>;
        log(): Observable<T>;
        raf(fn?: (val: T) => void): Observable<T>;
    }
}
export type ArrayElement<ArrayType extends readonly unknown[]> = ArrayType extends readonly (infer ElementType)[] ? ElementType : never;
export type Size = ArrayElement<typeof SizeValues>;
export interface ElementWithValue<T> extends HTMLElement {
    value: T;
}
export declare const SizeValues: readonly [-2, -1, 0, 1, 2, 3, 4, 5, "small", "big"];
export declare const FocusMask: {
    readonly mask: {
        readonly position: "absolute";
        readonly left: 0;
        readonly right: 0;
        readonly bottom: 0;
        readonly top: 0;
        readonly backgroundColor: "onSurface";
        readonly opacity: 0;
    };
    readonly mask$hover: {
        readonly opacity: import("@cxl/ui/css.js").Variable<number>;
    };
    readonly mask$focusVisible: {
        readonly opacity: import("@cxl/ui/css.js").Variable<number>;
    };
};
export declare const maskStyles: () => HTMLStyleElement;
export declare function is<T>(equalTo: T): (source: Observable<T, "none">) => Observable<boolean, "none">;
export declare function log<T>(): Operator<T>;
export declare function getAttribute<T extends Node, K extends ComponentAttributeName<T>>(el: T, name: K): Observable<T[K], "none">;
export declare function displayContents(): Node;
export declare function changeEvent(host: Component & {
    value: unknown;
}): Observable<unknown, "none">;
export declare function mask(): HTMLElement;
export declare function persistWithParameter(prefix: string): Operator<AttributeEvent<Component>, AttributeEvent<Component>>;
export declare function getTarget<T extends Component, K extends ComponentAttributeName<T>>(host: T, prop: K): Observable<Exclude<T[K], string>, "none">;
export declare function PrefixAttribute(prefix: string): <T extends Component>(target: T, attribute: ComponentAttributeName<T>, descriptor?: PropertyDescriptor) => any;
export declare function NumberAttribute(min?: number, max?: number): <T extends Component>(target: T, attribute: ComponentAttributeName<T>, descriptor?: PropertyDescriptor) => any;
export declare function SizeAttribute(fn: (size: Exclude<Size, 'small' | 'big'>) => Record<string, StyleDefinition>): <T extends Component>(target: T, attribute: ComponentAttributeName<T>, descriptor?: PropertyDescriptor) => any;
export declare function ForegroundColorAttribute(defaultColor?: SurfaceColorValue): <T extends Component>(target: T, attribute: ComponentAttributeName<T>, descriptor?: PropertyDescriptor) => any;
export declare function ColorAttribute(defaultColor?: SurfaceColorValue): <T extends Component>(target: T, attribute: ComponentAttributeName<T>, descriptor?: PropertyDescriptor) => any;
export declare function CssAttribute(styles: Styles): <T extends Component>(target: T, attribute: ComponentAttributeName<T>, descriptor?: PropertyDescriptor) => any;
export declare function breakpoint(el: HTMLElement): Observable<BreakpointKey>;
export declare function breakpointClass(el: HTMLElement): Observable<string, "none">;
type VoidEvent = {
    [K in keyof CustomEventMap]: CustomEventMap[K] extends void ? K : never;
}[keyof CustomEventMap];
export declare function message<K extends VoidEvent>(el: EventTarget, event: K): void;
export declare function message<K extends keyof CustomEventMap>(el: EventTarget, event: K, detail: CustomEventMap[K]): void;
export declare function onMessage<K extends keyof CustomEventMap>(el: EventTarget, event: K, stopPropagation?: boolean): Observable<CustomEventMap[K]>;
export {};
