/// <amd-module name="@cxl/ui/css.js" />
export type StyleDefinition<T extends Theme = Theme> = {
    [K in keyof StrictStyleDefinition<T>]?: StrictStyleDefinition<T>[K] | Variable<StrictStyleDefinition<T>[K]>;
};
export type BaseColor = RGBA;
export type CSSStyle = {
    [P in keyof CSSStyleDeclaration]?: string | number;
};
export type Color<T extends Theme> = keyof T['colors'] | BaseColor | 'currentColor' | 'inherit' | 'transparent';
export type Percentage = '50%' | '100%' | CustomPercentage;
export type Calc = `calc(${string})`;
export type Length = number | Percentage | Calc | 'auto';
export type ColorVariables<T> = {
    [K in keyof T]: string;
};
export type VariableList<T extends Theme> = T['variables'] & ColorVariables<T['colors']>;
export type FlexAlign = 'normal' | 'stretch' | 'center' | 'start' | 'end' | 'flex-start' | 'flex-end' | 'baseline';
export type StyleKey<T extends Theme> = keyof StrictStyleDefinition<T>;
export interface Variables {
}
export interface Colors {
}
export interface FontDefinition {
    family: string;
    url: string;
    weight?: string;
}
export interface Typography {
    default: CSSStyle;
}
export interface StrictStyleDefinition<T extends Theme> {
    alignItems: FlexAlign;
    alignSelf: FlexAlign;
    animation: keyof T['animation'];
    animationDuration: string;
    backgroundImage: string;
    backgroundClip: 'content-box' | 'border-box';
    backgroundColor: Color<T>;
    backgroundSize: 'cover' | 'contain';
    backgroundPosition: 'center';
    backgroundRepeat: 'no-repeat' | 'repeat' | 'repeat-x' | 'repeat-y';
    borderBottom: Length;
    borderLeft: Length;
    borderRight: Length;
    borderTop: Length;
    borderColor: Color<T>;
    borderWidth: number;
    borderRadius: Length;
    borderStyle: 'solid' | 'dashed' | 'dotted' | 'double' | 'none';
    boxShadow: BoxShadow<T> | 'none';
    boxSizing: 'border-box';
    clipPath: string;
    fill: Color<T>;
    stroke: Color<T>;
    elevation: 0 | 1 | 2 | 3 | 4 | 5;
    fontSize: number | 'inherit';
    fontStyle: 'italic';
    touchAction: 'none' | 'pan-y' | 'pan-x';
    translateX: Length;
    translateY: Length;
    rowGap: Length;
    columnGap: Length;
    gridAutoColumns: string;
    gridColumnEnd: string;
    gridAutoFlow: 'column' | 'row';
    gridTemplateColumns: string;
    gridTemplateRows: string;
    gridRow: string;
    prepend: string;
    rotate: number;
    scaleX: number;
    scaleY: number;
    font: keyof T['typography'];
    color: Color<T>;
    paddingLeft: Length;
    paddingRight: Length;
    paddingTop: Length;
    paddingBottom: Length;
    marginLeft: number | 'auto';
    marginRight: number | 'auto';
    marginTop: number | 'auto';
    marginBottom: number | 'auto';
    opacity: number;
    outline: number | string;
    outlineOffset: number;
    order: number;
    overflowY: 'hidden' | 'visible' | 'auto';
    overflowX: 'hidden' | 'visible' | 'auto';
    visibility: 'hidden' | 'visible';
    transformOrigin: string;
    overflowScrolling: string;
    lineHeight: number | 'unset';
    listStyleImage: string;
    listStylePosition: 'inside' | 'outside';
    listStyleType: 'none' | 'inherit' | 'initial' | 'unset';
    width: Length | 'max-content' | 'min-content';
    tableLayout: 'fixed' | 'auto';
    top: Length;
    left: Length;
    right: Length;
    bottom: Length;
    filter: string;
    flexGrow: number;
    flexShrink: number;
    flexBasis: Length;
    flexDirection: string;
    flexWrap: 'wrap';
    justifyContent: string;
    pointerEvents: string;
    cursor: string;
    display: 'block' | 'inline' | 'table' | 'flex' | 'inline-grid' | 'grid' | 'table-row' | 'table-caption' | 'table-row-group' | 'table-cell' | 'contents' | 'none' | 'initial' | 'inline-flex' | 'inline-block' | 'inherit';
    position: 'static' | 'relative' | 'absolute' | 'sticky' | 'fixed';
    userSelect: string;
    textAlign: string;
    textDecoration: string;
    textOverflow: 'ellipsis';
    textTransform: 'uppercase' | 'capitalize' | 'none';
    transition: string;
    height: Length;
    minHeight: Length | 'none';
    minWidth: Length | 'none';
    maxHeight: Length | 'none';
    maxWidth: Length | 'none';
    mixBlendMode: 'difference';
    variables: Partial<VariableList<T>>;
    verticalAlign: 'top' | 'middle' | 'bottom' | 'super' | 'sub' | 'text-top' | 'text-bottom' | 'baseline';
    willChange: 'transform';
    whiteSpace: 'nowrap' | 'pre-wrap' | 'pre';
    wordBreak: 'break-all';
    zIndex: number;
}
export interface BoxShadow<T extends Theme = Theme> {
    offsetX: number;
    offsetY: number;
    blurRadius: number;
    spread: number;
    color: Color<T>;
}
export type StylesOnly<T extends Theme> = {
    [key: string]: StyleDefinition<T>;
};
export type Styles<T extends Theme> = StylesOnly<T> | {
    '@small'?: StylesOnly<T>;
    '@medium'?: StylesOnly<T>;
    '@large'?: StylesOnly<T>;
    '@xlarge'?: StylesOnly<T>;
    '@xxlarge'?: StylesOnly<T>;
};
export type BreakpointKey = 'xsmall' | 'small' | 'medium' | 'large' | 'xlarge' | 'xxlarge';
export type CSSUnit = 'px' | 'em' | 'rem';
export interface Breakpoints {
    xsmall: number;
    small: number;
    large: number;
    medium: number;
    xlarge: number;
    xxlarge: number;
}
export interface AnimationDefinition {
    kf: Keyframe[];
    options?: KeyframeAnimationOptions;
}
export interface Animation {
    none: undefined;
}
export interface Theme {
    animation: Animation;
    colors: Colors;
    typography: {
        default: CSSStyle;
    };
    variables: Variables;
    breakpoints: Breakpoints;
    imports?: readonly string[];
    unit: CSSUnit;
}
export interface RGBA {
    readonly a: number;
    readonly r: number;
    readonly g: number;
    readonly b: number;
    toString(): string;
}
export type CustomPercentage = {
    __pct: true;
    toString(): string;
};
export declare function boxShadow<T extends Theme>(offsetX: number, offsetY: number, blurRadius: number, spread: number, color: Color<T>): {
    offsetX: number;
    offsetY: number;
    blurRadius: number;
    spread: number;
    color: Color<T>;
};
export declare function pct(n: number): CustomPercentage;
export declare const defaultTheme: Theme;
export declare function padding(paddingTop: number | 'auto', paddingRight?: number | "auto", paddingBottom?: number | "auto", paddingLeft?: number | "auto"): {
    paddingTop: number | "auto";
    paddingRight: number | "auto";
    paddingBottom: number | "auto";
    paddingLeft: number | "auto";
};
export declare function margin(marginTop: number | 'auto', marginRight?: number | "auto", marginBottom?: number | "auto", marginLeft?: number | "auto"): {
    marginTop: number | "auto";
    marginRight: number | "auto";
    marginBottom: number | "auto";
    marginLeft: number | "auto";
};
export declare function border(borderTop: number | 'auto', borderRight?: number | "auto", borderBottom?: number | "auto", borderLeft?: number | "auto"): {
    borderTop: number | "auto";
    borderRight: number | "auto";
    borderBottom: number | "auto";
    borderLeft: number | "auto";
};
export declare function rgba(r: number, g: number, b: number, a?: number): RGBA;
export declare function mask({ r, g, b, a }: RGBA): string;
export declare function renderVariables(variables: Variables): string;
export type PartialTheme = {
    variables?: Partial<Variables>;
    typography?: Record<string, CSSStyle>;
    colors?: Colors;
    imports?: readonly string[];
    globalCss?: string;
    override?: Record<string, string>;
};
export declare function renderGlobal(theme: PartialTheme): string;
export declare class Variable<T> {
    readonly name: string;
    constructor(name: string);
    readonly __brand?: T;
    toString(): string;
}
export declare const White: RGBA;
export declare const White8: string;
export declare const White12: string;
export declare const White87: string;
export declare function buildTheme<T extends Theme>(theme: T): {
    inline: (def: StyleDefinition) => string;
    render: (styles: Styles<T>, baseSelector?: string) => string;
    applyTheme: (container?: HTMLHeadElement) => void;
    rootStyles: HTMLStyleElement;
    variable: {
        <K extends keyof T["colors"]>(name: K): Variable<T["colors"][K]>;
        <K extends keyof T["variables"]>(name: K): Variable<T["variables"][K]>;
    };
    style(styles: Styles<T>, selector?: string): () => HTMLStyleElement;
    baseColor(name: keyof T["colors"]): string;
};
