/// <amd-module name="@cxl/ui/dataset-bind.js" />
import { Component } from './component.js';
/**
 * The cxl-bind component provides a mechanism to dynamically bind data from a dataset record
 * to the content or attributes of an element.
 * It simplifies data binding within your web application's templates.
 *
 * Typical Uses:
 * - Populating elements with dynamic text content based on data from a dataset.
 * - Updating element attributes using values from the dataset.
 * - Creating reusable templates that can adapt to different data sources.
 *
 * Special Handlers: It defines specific logic for attributes named `$text` and `$html`.
 * These attributes directly update the element's text content or inner HTML, respectively.
 *
 * Content Binding: When a render event is triggered, the component checks for a valid dataset record.
 * If a record exists and there are child elements, it applies each binding function to each child element,
 * updating content or attributes based on the data record.
 * If there are no children, it applies the binding functions directly to the cxl-bind element itself.
 *
 * @beta
 */
export declare class Bind extends Component {
}
/**
 * The cxl-bind-model component establishes a two-way data binding between a dataset record and a DOM element.
 * It allows you to synchronize changes made in the UI element with the underlying data source.
 *
 * The BindModel component requires its element to be a descendant of a `cxl-dataset-record` component.
 * This ensures it has access to the relevant data source.
 *
 * Typical Uses:
 * - Creating editable form fields that update a dataset record.
 * - Binding input elements (text, number, etc.) to data properties.
 * - Simplifying data flow between UI and data models in your application.
 *
 * @beta
 */
export declare class BindModel extends Component {
    /**
     * Specifies the field name within the dataset record to bind to.
     */
    field?: string;
    /**
     * Defines the property name of the DOM element to bind the data to.
     */
    prop: string;
}
