/// <amd-module name="@cxl/ui/dataset-select.js" />
import { Checkbox } from './checkbox.js';
/**
 * Component to select all elements in a Datatable
 *
 * @demo
 * <cxl-datatable>
 *   <cxl-tr>
 *     <cxl-th><cxl-dataset-select-all></cxl-dataset-select-all></cxl-th>
 *     <cxl-th>Column 1</cxl-th>
 *   </cxl-tr>
 *   <cxl-dtr source="row1">
 *     <cxl-td-select selected></cxl-td-select>
 *     <cxl-td>Selectable Row 1</cxl-td>
 *   </cxl-dtr>
 *   <cxl-dtr source="row2">
 *     <cxl-td-select selected></cxl-td-select>
 *     <cxl-td>Selectable Row 2</cxl-td>
 *   </cxl-dtr>
 * </cxl-datatable>
 */
export declare class DatasetSelectAll extends Checkbox {
}
/**
 * The DatasetSelect component provides a mechanism for selecting items from a dataset within your application.
 * It leverages the Checkbox component and dataset functionalities.
 *
 * @beta
 * @demo
<cxl-dataset id="dataSet">
    <cxl-each-record>
        <template>
            <cxl-dataset-select>
                <cxl-bind $text="name"></cxl-bind>,
                <cxl-bind $text="color"></cxl-bind>
            </cxl-dataset-select>
        </template>
    </cxl-each-record>
</cxl-dataset>
<script>
    dataSet.source = [
        { "name": "Apple", "color": "red" },
        { "name": "Orange", "color": "green" },
        { "name": "Apple", "color": "green" },
    ];
</script>
 */
export declare class DatasetSelect extends Checkbox {
}
