/// <amd-module name="@cxl/ui/datepicker.js" />
import { CustomInputBase } from './input-base.js';
/**
 * The Datepicker component is an input element that allows users to select a date and optionally a time.
 *
 * @example
 * <cxl-datepicker value="08/06/1984"></cxl-datepicker>
 */
export declare class Datepicker extends CustomInputBase {
    /**
     * This property holds the currently selected date as a Date object. It can be undefined if no date is selected.
     */
    value: Date | undefined;
    /**
     * This property determines whether the date picker allows selecting a time along with the date.
     * When set to true, the picker will include time selection options.
     */
    showtime: boolean;
    /**
     * This method attempts to focus the date picker element. If the component is disabled (disabled property is true), it won't attempt to focus.
     */
    focus(): void;
}
/**
 * The DatepickerToggle component is a button-like element designed to control the visibility of a corresponding Datepicker component.
 */
export declare class DatepickerToggle extends CustomInputBase {
    /**
     * This property determines the visibility state of the connected date picker. When set to true, the date picker will be displayed.
     */
    opened: boolean;
    /**
     * This optional property allows you to define a custom positioning function for the date picker.
     * This function receives the date picker element (el) as an argument.
     */
    position?: (el: HTMLElement) => void;
    /**
     * This property reflects the currently selected date from the connected Datepicker.
     */
    value: Date | undefined;
    /**
     * This property indicates whether the Datepicker allows selecting time along with the date.
     */
    showtime: boolean;
    /**
     * This method attempts to focus the toggle button.
     */
    focus(): void;
}
