/// <amd-module name="@cxl/ui/input-datepicker.js" />
import { DateFormat } from './datetime.js';
import { TextInputBase } from './input.js';
/**
 * The InputDatepicker component provides a user-friendly interface for selecting dates,
 * optionally with time. It consists of a text input field
 * paired with a clickable toggle button that reveals a calendar picker.
 *
 * @demo
 * <cxl-field>
 *   <cxl-label>Date</cxl-label>
 *   <cxl-input-datepicker value="2024-08-06"></cxl-input-datepicker>
 * </cxl-field>
 */
export declare class InputDatepicker extends TextInputBase {
    inputEl: HTMLInputElement;
    /** Binds to a Date object representing the selected date. */
    value: Date | undefined;
    /**
     * Optional configuration for date formatting.
     *
     * @demo
     * <cxl-field>
     *   <cxl-label>Date</cxl-label>
     *   <cxl-input-datepicker dateformat="full" value="08-06-1984"></cxl-input-datepicker>
     * </cxl-field>
     */
    dateformat?: DateFormat;
    /**
     * Boolean indicating whether to include time selection.
     *
     * @demo
     * <cxl-field>
     *   <cxl-label>Date</cxl-label>
     *   <cxl-input-datepicker showtime value="08-06-1984 02:30"></cxl-input-datepicker>
     * </cxl-field>
     */
    showtime: boolean;
}
