/// <amd-module name="@cxl/ui/item.js" />
import { Component } from './component.js';
/**
 * The ItemLayout component provides a basic building block for rendering items within a list or collection.
 * It offers a styled container for content and a selected style attribute for visual differentiation.
 *
 */
export declare class ItemLayout extends Component {
    /** A boolean attribute indicating whether the item is currently selected */
    selected: boolean;
}
/**
 * The ItemBase class serves as the base class for menu items and potentially other similar components.
 */
export declare class ItemBase extends Component {
    /** A boolean indicating whether the item is disabled. Reflected in the component's styles. */
    disabled: boolean;
    /** A boolean indicating whether the item is selected. Reflected in the component's styles. */
    selected: boolean;
    touched: boolean;
}
/**
 * The Item component represents a single item within a menu or list.
 * It provides a flexible container for displaying various content elements like icons, avatars, checkboxes, and text.
 *
 * specific
 * @example
 * <cxl-list>
 * <cxl-item><cxl-icon name="check" alt=""></cxl-icon> Single Line Icon</cxl-item>
 * <cxl-item><cxl-avatar alt=""></cxl-avatar> Single Line Avatar</cxl-item>
 * <cxl-item><cxl-checkbox>Single Line Checkbox</cxl-checkbox></cxl-item>
 * <cxl-item><cxl-avatar alt="" size="1"></cxl-avatar> Avatar and Checkbox <cxl-checkbox style="margin-left:auto" aria-label="selected item"></cxl-checkbox></cxl-item>
 * </cxl-list>
 */
export declare class Item extends ItemBase {
}
