/// <amd-module name="@cxl/ui/popup-dropdown.js" />
import { PopupPosition } from './popup.js';
import { Button } from './button.js';
import type { ToggleTarget } from './toggle.js';
/**
 * The `cxl-popup-dropdown` component displays a dropdown menu when clicked.
 *
 * @beta
 * @demo
    <cxl-popup-dropdown aria-label="alignment" target="popup">
        <cxl-icon name="format_align_left"></cxl-icon>
    </cxl-popup-dropdown>
    <cxl-popup aria-label="Alignment Menu" id="popup">
        <cxl-toolbar >
            <cxl-button aria-label="Align Left" flat>
                <cxl-icon name="format_align_left"></cxl-icon>
            </cxl-button>
            <cxl-button aria-label="Align Center" flat>
                <cxl-icon name="format_align_center"></cxl-icon>
            </cxl-button>
            <cxl-button aria-label="Align Right" flat>
                <cxl-icon name="format_align_right"></cxl-icon>
            </cxl-button>
        </cxl-toolbar>
    </cxl-popup>
 */
export declare class PopupDropdown extends Button {
    flat: boolean;
    /** A boolean style attribute indicating the popup's current visibility state (opened or closed). */
    opened: boolean;
    /** An attribute referencing the ID of the popup element it controls or a ToggleTarget object. */
    target?: string | ToggleTarget;
    position?: PopupPosition | ((el: HTMLElement) => void);
}
