/// <amd-module name="@cxl/ui/tree.js" />
import { Component } from './component.js';
declare module './registable.js' {
    interface RegistableMap {
        tree: TreeNode;
    }
}
/**
 * Container for TreeNode elements.
 * @see TreeNode
 */
export declare class Tree extends Component {
    closeAll(): void;
    openAll(): void;
}
/**
 * The TreeNode component creates interactive tree structures for displaying hierarchical data.
 *
 * @beta
 * @demo
<cxl-tree>
  <cxl-tree-node
    >Parent Node
    <cxl-tree-node
        >Child Node 1
        <cxl-tree-node iconopen="">Child Node 1</cxl-tree-node>
        <cxl-tree-node>Child Node 2</cxl-tree-node>
        <cxl-tree-node>Child Node 3</cxl-tree-node>
    </cxl-tree-node>
    <cxl-tree-node>Child Node 2</cxl-tree-node>
    <cxl-tree-node>Child Node 3</cxl-tree-node>
  </cxl-tree-node>
</cxl-tree>
 */
export declare class TreeNode extends Component {
    /** Determines whether a node is expanded  */
    opened: boolean;
    /** Indicates if a node is touched */
    touched: boolean;
    /** Disables a node, preventing interaction */
    disabled: boolean;
    nodes: Set<TreeNode>;
    /** Name of the icon for expanded state */
    iconopen: string;
    /** Name of the icon for collapsed state (can be empty) */
    iconclose: string;
    closeAll(): void;
    openAll(): void;
}
