/// <amd-module name="@cxl/ui/tsx.js" />
import { Observable } from './rx.js';
declare global {
    namespace dom {
        namespace JSX {
            type ElementClass = Bindable;
            interface ElementAttributesProperty {
                jsxAttributes: unknown;
            }
            interface ElementChildrenAttribute {
                children: {};
            }
            type Element = Node;
            type IntrinsicElements = {
                [P in keyof HTMLElementTagNameMap]: NativeType<HTMLElementTagNameMap[P]>;
            };
            interface IntrinsicClassAttributes<T> {
                $?: Binding<T, unknown> | Observable<unknown>;
            }
        }
    }
}
export type Binding<T, DataT> = (el: T) => Observable<DataT>;
export type Child = string | Node | number | ((host: Bindable) => Node) | undefined | Observable<unknown>;
export type Children = Child | Child[];
export type NativeChild = string | number | Node | undefined;
export type NativeChildren = NativeChild | NativeChild[];
export type NativeType<T> = {
    [K in keyof Omit<T, 'children'>]?: T[K];
} & {
    children?: NativeChildren;
};
export type Disallowed = Observable<unknown> | Function;
export type AttributeType<T> = {
    [K in keyof Omit<T, 'children' | '$'>]?: T[K] extends Disallowed ? never : T[K] | Observable<T[K]>;
} & {
    children?: Children;
};
export interface Bindable extends Node {
    bind(binding: Observable<unknown>): void;
}
export declare function expression(host: Bindable, binding: Observable<unknown>): Text;
export declare function renderChildren(host: Bindable | Node, children: Children, appendTo?: Node): void;
interface ComponentConstructor<T extends Bindable> {
    create(): T;
}
export declare function dom<T extends Bindable>(elementType: ComponentConstructor<T>, attributes?: AttributeType<T>, ...children: Child[]): T;
export declare function dom<T, T2>(elementType: (attributes?: T2) => Bindable, attributes?: T2, ...children: Child[]): T;
export declare function dom<K extends keyof HTMLElementTagNameMap>(elementType: K, attributes?: NativeType<HTMLElementTagNameMap[K]>, ...children: Child[]): HTMLElementTagNameMap[K];
export default dom;
