/// <amd-module name="@cxl/ui/typography.js" />
import { Component } from './component.js';
import { UiTheme } from './theme.js';
/**
 * The cxl-t component offers a foundation for displaying text with predefined styles and optional semantic variations.
 *
 * The component offers built-in styles for headings (h1 to h6) with appropriate font sizes and margins.
 * You can use the component without any specific style attribute to render standard body text with default styling.
 *)
 * @demo
 * <cxl-t h4>Heading 4</cxl-t>
 * <cxl-t h5>Heading 5</cxl-t>
 * <cxl-t h6>Heading 6</cxl-t>
 */
export declare class T extends Component {
    /**
     * This attribute allows you to apply a custom font from your application's theme typography definitions.
     * The value should correspond to a key of the UiTheme['typography'] interface.
     */
    font?: keyof UiTheme['typography'];
    /**
     * This attribute controls the text alignment within the component. It can be set to either "center" or "justify".
     */
    align?: 'center' | 'justify';
    /** @deprecated Use align */
    center: boolean;
    /**
     *  This style attribute sets the display style of the component to "inline", removing margins and allowing you to place text inline with surrounding content.
     *
     * @demo
     * <cxl-c>
     *   <cxl-t inline>Hello</cxl-t> <cxl-t inline>World!</cxl-t>
     * </cxl-c>
     * <cxl-t inline>Block Text</cxl-t>
     */
    inline: boolean;
}
