import { Component } from './component.js';
import type { ToggleTarget } from './toggle.js';
/**
 * The AppbarMenu component is used to create a menu that can be triggered from an app bar.
 * It provides a way to display additional options or functionalities within the app bar itself.
 *
 * The component adjusts its layout based on screen size.
 * - On smaller screens, the tabs are hidden and the menu trigger becomes visible.
 * - On larger screens, the tabs and the CTA button become visible.
 *
 * @beta
 *
 * @example
 * <cxl-appbar>
 *   <cxl-appbar-title>Title</cxl-appbar-title>
 *   <cxl-appbar-menu target="menu1" right>
 *     <cxl-tab selected>Home</cxl-tab>
 *     <cxl-tab>Support</cxl-tab>
 *     <cxl-tab>FAQs</cxl-tab>
 *     <cxl-button outline slot="cta">
 *       <cxl-icon name="shopping_cart"></cxl-icon>
 *       Buy License</cxl-button>
 *   </cxl-appbar-menu>
 * </cxl-appbar>
 * <cxl-menu id="menu1">
 *   <cxl-item>Home</cxl-item>
 *   <cxl-item>Support</cxl-item>
 *   <cxl-item>FAQs</cxl-item>
 *   <cxl-hr></cxl-hr>
 *   <cxl-item-layout>
 *     <cxl-button outline>
 *       <cxl-icon name="shopping_cart"></cxl-icon>
 *       Buy License</cxl-button>
 *   </cxl-item-layout>
 * </cxl-menu>
 */
export declare class AppbarMenu extends Component {
    /** The target attribute allows you to associate the AppbarMenu with a separate menu component. */
    target?: string | ToggleTarget;
    right: boolean;
}
