import { CustomInputBase } from './input-base.js';
import { Appbar } from './appbar.js';
import { IconButton } from './icon-button.js';
import { Input } from './input.js';
/**
 * Search input component specifically designed for use within an Appbar.
 * Manages both a visible input field on desktop and a clickable search icon on mobile.
 *
 * @demo
 * <cxl-appbar>
 *   <cxl-appbar-title>Appbar Title</cxl-appbar-title>
 *   <cxl-appbar-search></cxl-appbar-search>
 * </cxl-appbar>
 * @beta
 * @see Appbar
 */
export declare class AppbarSearch extends CustomInputBase {
    /**
     * Controls visibility of the search input.
     */
    opened: boolean;
    /** Specifies a more compact layout. */
    dense: boolean;
    desktopInput?: Input;
    mobileInput?: Input;
    protected mobileIcon?: IconButton;
    protected appbar?: Appbar;
    /** Holds the current search query. */
    value: string;
    /** Expands the search input for user interaction. */
    open(): void;
    /** Focuses the appropriate input element. */
    focus(): void;
}
