import { AutocompleteBase } from './autocomplete-base.js';
export { AutocompleteInput } from './autocomplete-base.js';
import type { Option } from './option.js';
/**
 * Enhanced text input field that suggests options to users as they type.
 * It combines a textbox with a dropdown list that displays filtered options based on the user's input.
 *
 * @beta
 * @demo
 * <cxl-field><cxl-label>Auto Complete</cxl-label>
 *   <cxl-autocomplete-input></cxl-autocomplete-input>
 *   <cxl-autocomplete aria-label="autocomplete list">
 *     <cxl-option value="green">Green</cxl-option>
 *     <cxl-option value="red">Red</cxl-option>
 *     <cxl-option value="blue">Blue</cxl-option>
 *     <cxl-option value="white">White</cxl-option>
 *   </cxl-autocomplete>
 * </cxl-field>
 */
export declare class Autocomplete extends AutocompleteBase {
    /**
     * Matching function. By default it will match the input value to the option textContent, case insensitive
     */
    matcher: (term: string) => (option: Option) => boolean;
    protected handleSearch(term: string): void;
}
