import { Component } from './component.js';
import type { CalendarEventData } from './calendar-event.js';
export declare class CalendarEventList extends Component {
    start: Date;
    end: Date;
    events: CalendarEventData[];
    period: number;
    periodrows: number;
}
/**
 * Renders a calendar day view for each date within a specified date range and displays any associated events for those days.
 *
 * @demo
 * <cxl-calendar-day start="1984-08-06" end="1984-08-08">
 *   <cxl-calendar-event start="1984-08-04" end="1984-08-10T01:00">Calendar Event</cxl-calendar-event>
 *   <cxl-calendar-event start="1984-08-08" end="1984-08-10T01:00">Calendar Event</cxl-calendar-event>
 *   <cxl-calendar-event start="1984-08-06" end="1984-08-07T01:00">Calendar Event</cxl-calendar-event>
 *   <cxl-calendar-event start="1984-08-06" end="1984-08-06T01:00">Calendar Event</cxl-calendar-event>
 *   <cxl-calendar-event start="1984-08-06 10:00 AM" end="1984-08-06 11:00 AM">Calendar Event</cxl-calendar-event>
 *   <cxl-calendar-event start="1984-08-06T23:00" end="1984-08-07T01:00">Calendar Event</cxl-calendar-event>
 * </cxl-calendar-day>
 */
export declare class CalendarDay extends Component {
    /**
     * An array of event data objects used to populate the calendar view.
     */
    events: CalendarEventData[];
    /**
     * The starting date of the range for which to render calendar days. Defaults to the current date.
     */
    start: Date;
    /**
     * The ending date of the range for which to render calendar days. Defaults to the current date.
     */
    end: Date;
}
