import { CustomInputBase } from './input-base.js';
/**
 * The Checkbox component represents a checkbox UI element that allows users to select one or more options from a set.
 * It can be used to turn an option on or off.
 *
 * @example
 * <cxl-checkbox checked>Checkbox Label</cxl-checkbox>
 * <cxl-checkbox checked disabled>Disabled Checkbox</cxl-checkbox>
 */
export declare class Checkbox extends CustomInputBase {
    /**
     * This attribute represents the underlying value of the checkbox.
     * By default, it's set to false if not explicitly defined. When checked, the value becomes true.
     * If the checkbox is indeterminate, the value becomes undefined.
     */
    value: boolean | undefined;
    /**
     * Controls the checked state of the checkbox. When set to true, the checkbox is visually checked.
     *
     * @example
     * <cxl-checkbox aria-label="checked checkbox" checked></cxl-checkbox>
     */
    checked: boolean;
    /**
     * Controls the indeterminate state of the checkbox.
     * In this state, the checkbox displays a dash (-) and its value becomes undefined.
     *
     * @example
     * <cxl-checkbox aria-label="indeterminate checkbox" indeterminate></cxl-checkbox>
     */
    indeterminate: boolean;
    /**
     * When set to true, the checkbox is displayed inline-block, allowing for horizontal arrangement of multiple checkboxes.
     *
     * @example
     * <cxl-checkbox inline>Checkbox 1</cxl-checkbox>
     * <cxl-checkbox inline>Checkbox 2</cxl-checkbox>
     */
    inline: boolean;
}
