import { AttributeType, Children } from './tsx.js';
import { Observable, Operator, OrderedSubject } from './rx.js';
type RenderFunction<T> = (node: T) => void;
type Augmentation<T extends Component> = (host: T) => Node | Comment | Observable<unknown> | void;
type ComponentConstructor = {
    tagName: string;
    observedAttributes: string[];
    create(): Component;
};
export type ComponentAttributeName<T> = keyof T;
export interface AttributeEvent<T> {
    target: T;
    attribute: ComponentAttributeName<T>;
}
export declare class Bindings {
    private subscriptions?;
    bindings?: Observable<unknown>[];
    bind(binding: Observable<unknown>): void;
    connect(): void;
    disconnect(): void;
}
export declare abstract class Component extends HTMLElement {
    static tagName: string;
    static observedAttributes: string[];
    static create(): Component;
    private $$bindings?;
    private $$prebind?;
    protected jsxAttributes: AttributeType<this>;
    readonly render?: (node: HTMLElement) => void;
    readonly attributes$: OrderedSubject<unknown>;
    Shadow: (p: {
        children: Children;
    }) => Component;
    Slot: (p: {
        selector: string;
        name?: string;
        className?: string;
    }) => HTMLSlotElement;
    bind(obs: Observable<unknown>): void;
    protected connectedCallback(): void;
    protected disconnectedCallback(): void;
    protected attributeChangedCallback(name: keyof this, oldValue: string | null, value: string | null): void;
}
export declare function pushRender<T extends Component>(proto: T, renderFn: RenderFunction<T>): void;
export declare function appendShadow<T extends Component>(host: T, child: Node | Observable<unknown>): void;
export declare function augment<T extends Component>(constructor: typeof Component, decorators: Augmentation<T>[]): void;
export declare function registerComponent(tagName: string, ctor: ComponentConstructor): void;
export declare function Augment(): (ctor: ComponentConstructor) => void;
export declare function Augment<T extends Component>(...augs: [string | Augmentation<T> | void, ...Augmentation<T>[]]): (ctor: ComponentConstructor) => void;
export declare function connect<T extends Component>(bindFn: (node: T) => void): (host: T) => void;
export declare function onUpdate<T extends Component>(host: T): Observable<T, "none">;
/**
 * Fires when connected and on attribute change
 */
export declare function update<T extends Component>(fn: (node: T) => void): (host: T) => void;
export declare function attributeChanged<T extends Component, K extends ComponentAttributeName<T>>(element: T, attribute: K): Observable<T[K]>;
export declare function get<T extends Component, K extends ComponentAttributeName<T>>(element: T, attribute: K): Observable<T[K]>;
interface AttributeOptions<T extends Component> {
    persist?: boolean;
    persistOperator?: Operator<AttributeEvent<T>, AttributeEvent<T>>;
    observe?: boolean;
    render?: RenderFunction<T>;
    parse?(val: unknown, component: T): unknown;
}
export declare function Attribute(options?: AttributeOptions<Component>): <T extends Component>(target: T, attribute: ComponentAttributeName<T>, descriptor?: PropertyDescriptor) => any;
export declare function StyleAttribute(): <T extends Component>(target: T, attribute: ComponentAttributeName<T>, descriptor?: PropertyDescriptor) => any;
export declare function EventAttribute(): <T extends Component>(target: T, attribute: keyof T, descriptor?: PropertyDescriptor) => any;
export declare function Property(): <T extends Component>(target: T, attribute: ComponentAttributeName<T>, descriptor?: PropertyDescriptor) => any;
export declare function getRegisteredComponents(): {
    [x: string]: typeof Component;
};
export declare class Span extends Component {
}
export declare function Slot(): HTMLSlotElement;
export {};
