import { Component } from './component.js';
import { Navigation } from './navigation.js';
/**
 * The DatatablePagination component provides a set of controls for paginating data within a Datatable component.
 * It allows users to navigate through large datasets by changing the displayed page and adjusting the number
 * of rows per page.
 *
 * Typical Uses:
 * - Implementing user-friendly pagination for data tables.
 * - Enabling users to control the amount of data shown at once.
 *
 * @demo
 * <cxl-datatable>
 *   <cxl-dtr source="row1">
 *     <cxl-td-select></cxl-td-select>
 *     <cxl-td>Selectable Row 1</cxl-td>
 *   </cxl-dtr>
 *   <cxl-dtr source="row2">
 *     <cxl-td-select></cxl-td-select>
 *     <cxl-td>Selectable Row 2</cxl-td>
 *   </cxl-dtr>
 *   <cxl-datatable-pagination slot="footer" rows="1"></cxl-datatable-pagination>
 * </cxl-datatable>
 */
export declare class DatatablePagination extends Component {
    /** The initial number of rows displayed per page. */
    rows: number;
    /** An array of numbers specifying the available options for rows per page in the selector. */
    options: number[];
    /** The initial page number */
    page: number;
    /** The total number of items in the dataset (automatically updated based on the dataset). */
    readonly total = 0;
    /** The total number of pages available based on the dataset size and rows per page (automatically calculated). */
    readonly totalPages = 0;
    protected navigation?: Navigation;
    /** Navigates to the first page of the dataset. */
    goFirst(): void;
    /**  Navigates to the next page of the dataset.*/
    goNext(): void;
    /** Navigates to the previous page of the dataset. */
    goPrevious(): void;
    /** Navigates to the last page of the dataset. */
    goLast(): void;
}
