import { Observable, Subject, Subscriber, Subscription } from './rx.js';
declare global {
    interface Node {
        $$attributeObserver?: AttributeObserver;
        $$childrenObserver?: ChildrenObserver;
    }
}
export type ElementContent = string | Node | undefined;
export type TemplateContent = string | Element | HTMLTemplateElement | NodeList;
export declare function empty(el: Element | DocumentFragment): void;
export declare function setContent(el: Element, content: ElementContent): void;
export declare function on<K extends keyof WindowEventMap>(element: Window, event: K, options?: AddEventListenerOptions): Observable<WindowEventMap[K]>;
export declare function on<K extends keyof HTMLElementEventMap>(element: EventTarget, event: K, options?: AddEventListenerOptions): Observable<HTMLElementEventMap[K]>;
export declare function on<T extends HTMLElement, K extends string>(element: T, event: K, options?: AddEventListenerOptions): Observable<CustomEvent<EventDetail<T, K>>>;
export declare function onKeypress(el: Element | Window, key?: string, options?: AddEventListenerOptions): Observable<KeyboardEvent, "none">;
export declare function onAction(el: Element): Observable<MouseEvent, "none">;
export declare function onReady(): Observable<boolean, "none">;
export declare function onLoad(): Observable<boolean, "none">;
export declare function onFontsReady(): Observable<FontFaceSet>;
export declare function getShadow(el: Element): ShadowRoot;
export declare function setAttribute(el: Element, attr: string, val: unknown): unknown;
export declare function trigger<K extends keyof HTMLElementEventMap | keyof WindowEventMap>(el: EventTarget, event: K, options?: CustomEventInit): void;
export declare function trigger<T extends HTMLElement, K extends string>(el: T, event: K, options: CustomEventInit<EventDetail<T, K>>): void;
export type AttributeMutationEvent<T extends EventTarget> = {
    type: 'attribute';
    target: T;
    value: unknown;
};
export type MutationEvent<T extends EventTarget = EventTarget> = {
    type: 'added' | 'removed';
    target: T;
    value: Node;
} | {
    type: 'characterData';
    target: T;
} | AttributeMutationEvent<T>;
export declare class AttributeObserver extends Subject<AttributeMutationEvent<EventTarget>> {
    element: Node;
    observer?: MutationObserver;
    bindings?: Subscription[];
    $onMutation(events: MutationRecord[]): void;
    $initializeNative(element: Node): void;
    constructor(element: Node);
    protected onSubscribe(subscription: Subscriber<MutationEvent<EventTarget>>): () => void;
    disconnect(): void;
    trigger(attributeName: string): void;
}
export declare function observeChildren(el: Element): Observable<void>;
export declare function onChildrenMutation(el: Element): ChildrenObserver;
export declare function onAttributeChange(el: Element): AttributeObserver;
export declare class ChildrenObserver extends Subject<MutationEvent> {
    private element;
    private observer?;
    constructor(element: Element);
    $handleEvent(ev: MutationRecord): void;
    protected onSubscribe(subscription: Subscriber<MutationEvent<EventTarget>>): () => void;
}
export declare function onHashChange(): Observable<string, "none">;
export declare function onHistoryChange(): Observable<any, "none">;
export declare function onLocation(): Observable<Location, "none">;
export declare const animationFrame: Observable<number, "none">;
export declare function findNextNode<T extends ChildNode>(el: T, fn: (el: T) => boolean, direction?: 'nextSibling' | 'previousSibling'): T | undefined;
export declare function findNextNodeBySelector(host: Element, el: Element, selector: string, direction?: number): Element | null;
export declare function onResize(el: Element): Observable<unknown, "none">;
export declare function insert(el: Element, content: ElementContent): void;
export declare function fileReaderString(file: Blob): Observable<string, "none">;
export declare function onMutation(target: Node, options?: MutationObserverInit): Observable<MutationEvent<EventTarget>, "none">;
export declare function onIntersection(target: Element): Observable<IntersectionObserverEntry, "none">;
export interface ElementWithValue<T> extends HTMLElement {
    value: T;
}
export declare function onValue<T extends ElementWithValue<R>, R = T['value']>(el: T): Observable<R, "none">;
export declare function onVisible(target: Element): Observable<boolean, "none">;
export declare function isHidden(target: HTMLElement): boolean;
export declare function isFocusable(el: HTMLElement): boolean;
export declare function findFocusable(host: Element | ShadowRoot): HTMLElement | undefined;
export declare function findLastFocusable(host: Element | ShadowRoot): HTMLElement | undefined;
export declare function findFocusableAll(host: Element): HTMLElement[];
export declare function setClassName(el: HTMLElement): import("./rx.js").Operator<string, string>;
export declare function debounceImmediate<A extends unknown[], R>(fn: (...a: A) => R): (this: unknown, ...args: A) => void;
export declare function debounceRaf<A extends unknown[], R>(fn: (...a: A) => R): (this: unknown, ...args: A) => void;
/**
 * debounce using requestAnimationFrame
 */
export declare function raf<T>(fn?: (val: T) => void): import("./rx.js").Operator<T, T>;
export declare const hovered: ($: Element) => Observable<boolean, "none">;
export declare const focused: ($: Element) => Observable<boolean, "none">;
export declare function nodeSort(a: Node, b: Node): 1 | -1;
export declare function sortNodes<T extends Node>(nodes: T[]): T[];
export type EventDetail<T, K extends string> = T[Extract<keyof T, `on${K}`>] extends ((e: CustomEvent<infer D>) => void) | undefined ? D : never;
