import { Component } from './component.js';
import { DragDropEvent } from './drag.js';
/**
 * The DragHandle component functions as a drag initiation point.
 * It allows dragging of either itself or a designated target element.
 *
 * @beta
 * @demo
<style>
    .cxl-drag-handle cxl-drag-handle { display: block; padding: 10px; margin: 5px; }
    .cxl-drag-handle cxl-drag-handle[dragging] { opacity: 0.7; }
    .cxl-drag-handle cxl-drag-handle[dragover] { background-color: #ddd; }
</style>
<div class="cxl-drag-handle" style="overflow:hidden">
    <cxl-drag-handle><span style="font-weight: bold;">Item 1</span></cxl-drag-handle>
    <cxl-drag-handle>Item 2</cxl-drag-handle>
    <cxl-drag-handle>
        <cxl-icon name="star" alt="Image 3"></cxl-icon>
    </cxl-drag-handle>
</div>
 */
export declare class DragHandle extends Component {
    /**
     * A boolean attribute that reflects the dragging state of the cxl-drag-swap element.
     * This attribute is set to true when the element is being dragged and false otherwise.
     */
    readonly dragging = false;
    /**
     * A boolean attribute that reflects whether another cxl-drag-swap element is currently being dragged over this element.
     * This attribute is set to true when a drag operation is in progress and the target drop zone is this element, and false otherwise.
     */
    readonly dragover = false;
    target?: HTMLElement | string;
    protected handleDrag(_ev: DragDropEvent): void;
}
