import { Component } from './component.js';
/**
 * The DragTarget acts as a container that listens for drag events and
 * updates its dragover attribute accordingly. This attribute specifically
 * indicates the position of the dragged element relative to the target
 * component, providing values like 'top left', 'top right', 'bottom left',
 * or ' bottom right'.
 *
 * @beta
 * @see DragHandle
 * @demo
<style>
    .cxl-drag-target cxl-drag-target { border: 4px solid transparent; flex-grow: 1 }
    .cxl-drag-target [dragging] { z-index: 10; opacity: 0.6 }
    .cxl-drag-target [dragover~="top"] { border-top-color: var(--cxl-primary); }
    .cxl-drag-target [dragover~="bottom"] { border-bottom-color: var(--cxl-primary); }
    .cxl-drag-target [dragover~="left"] { border-left-color: var(--cxl-primary); }
    .cxl-drag-target [dragover~="right"] { border-right-color: var(--cxl-primary); }
</style>
<cxl-flex class="cxl-drag-target" vflex gap="16" pad="16" style="overflow:hidden">
    <cxl-drag-target id="card1">
        <cxl-card pad="16">
            <cxl-drag-handle target="card1">
                <cxl-c pad="4" color="primary"> Drag Handle </cxl-c>
            </cxl-drag-handle>
        </cxl-card>
    </cxl-drag-target>
    <cxl-drag-target id="card2">
        <cxl-card pad="16">
            <cxl-drag-handle target="card2">
                <cxl-c pad="4" color="secondary"> Drag Handle </cxl-c>
            </cxl-drag-handle>
        </cxl-card>
    </cxl-drag-target>
</cxl-flex>
 */
export declare class DragTarget extends Component {
    readonly dragover?: `${'top' | 'bottom'} ${'left' | 'right'}`;
    ontargetdrop?: (ev: CustomEvent<{
        relatedTarget: HTMLElement;
        clientX: number;
        clientY: number;
    }>) => void;
}
