import { Observable } from './rx.js';
export interface DragOptions {
    target: HTMLElement;
    moveTarget?: HTMLElement;
    delay?: number;
}
export interface DragEffectsOptions extends DragOptions {
}
export interface DragMoveOptions extends DragOptions {
    axis?: 'x' | 'y';
}
interface DragLikeEvent {
    target: EventTarget | null;
    clientX: number;
    clientY: number;
}
export interface CustomDragEvent extends DragLikeEvent {
    target: HTMLElement;
    type: 'start' | 'end' | 'move';
}
export interface DragOverEvent extends DragLikeEvent {
    target: HTMLElement;
    type: 'over';
    relatedTarget: HTMLElement;
}
export interface DragOutEvent {
    target: HTMLElement;
    type: 'out';
}
export interface CustomDropEvent extends DragLikeEvent {
    target: HTMLElement;
    type: 'drop';
    relatedTarget: HTMLElement;
}
export type DragDropEvent = CustomDragEvent | DragOverEvent | CustomDropEvent | DragOutEvent;
export interface TouchGesture {
    type: 'swipe-left' | 'swipe-right';
}
export interface DragInsideEvent extends CustomDragEvent {
    startX: number;
    startY: number;
}
export declare function onTouchSwipe({ target, }: DragOptions): Observable<TouchGesture>;
export declare function mouseEvents(element: HTMLElement): Observable<CustomDragEvent, "none">;
export declare function touchEvents(element: HTMLElement): Observable<CustomDragEvent, "none">;
export declare const onMouseDrag: ({ target, moveTarget, delay }: DragOptions) => Observable<CustomDragEvent, "none">;
export declare const onTouchDrag: ({ target, moveTarget, delay }: DragOptions) => Observable<CustomDragEvent, "none">;
export declare function onDrag(options: DragOptions): Observable<CustomDragEvent, "none">;
/**
 * Converts drag events into relative percentages within the target's bounding rectangle, maintaining initial
 * touch points for drag-and-drop interactions. This is especially useful for implementing,
 * interactive UI components that respond to gesture-based position changes.
 */
export declare function dragInside(target: HTMLElement): Observable<DragInsideEvent, "none">;
export declare function dragOverElements(el: HTMLElement): Observable<DragOverEvent[], "none">;
export declare function onDragOver(target: HTMLElement): Observable<DragOverEvent | DragOutEvent, "none">;
export declare function onDrop(el: HTMLElement): Observable<CustomDropEvent, "none">;
export declare function onDropNative(el: HTMLElement): Observable<HTMLElement, "none">;
export interface DragMoveEvent {
    event: CustomDragEvent;
    x: number;
    y: number;
    sx: number;
    sy: number;
}
export declare function mapDragMove({ target, moveTarget, axis }: DragMoveOptions): (event: CustomDragEvent) => Observable<{
    event: CustomDragEvent;
    x: number;
    y: number;
    sx: number;
    sy: number;
}, "none">;
export declare function dragMoveApply(o: DragMoveOptions): ({ x, y }: DragMoveEvent) => void;
export declare function onDragMove(options: DragMoveOptions): Observable<{
    event: CustomDragEvent;
    x: number;
    y: number;
    sx: number;
    sy: number;
}, "none">;
export declare function dragMove(o: DragMoveOptions): Observable<{
    event: CustomDragEvent;
    x: number;
    y: number;
    sx: number;
    sy: number;
}, "none">;
export interface DragPositionInfo {
    dragPositionY: 'top' | 'bottom';
}
export declare function getDragPosition(element: HTMLElement, ev: DragLikeEvent): {
    dragPositionY: string;
    dragPositionX: string;
};
export declare function dragNative({ axis, target }: DragMoveOptions): Observable<DragEvent, "none">;
/**
 * Applies the dragover attribute for drop targets
 */
export declare function dropTarget<T extends HTMLElement>($: T): Observable<DragEvent, "none">;
export declare function swapChildren(a: Element, b: Element): void;
export declare function dragEffects(op: DragEffectsOptions): Observable<DragOverEvent | DragOutEvent | CustomDropEvent, "none">;
export declare function dragging(el: Element): Observable<boolean, "none">;
export declare function dragSwap(op: DragOptions): Observable<DragOverEvent | DragOutEvent | CustomDropEvent, "none">;
export {};
