import { Component } from './component.js';
import { BreakpointKey } from './css.js';
declare global {
    interface HTMLDialogElement {
        open: boolean;
        showModal(): void;
        show(): void;
        close(): void;
    }
}
/**
 * The Drawer component represents a drawer element that slides in from the left or right side of the screen.
 * It provides a way to display supplementary content alongside the main content area,
 * typically used for navigation, settings, or additional information.
 *
 * Typical Uses:
 * - Implementing navigation menus or sidebars.
 * - Presenting user settings and account options.
 * - Displaying contextual information related to the main content.
 * - Creating temporary views that don't require a full-blown dialog.
 *
 * @demo
 * <cxl-drawer position="right" visible>
 *   <cxl-c pad16>
 *     <cxl-t h6>Right Drawer Title</cxl-t>
 *     <cxl-t>Right Drawer Content</cxl-t>
 *   </cxl-c>
 * </cxl-drawer>
 */
export declare class Drawer extends Component {
    /** Controls the visibility of the drawer */
    visible: boolean;
    /**
     * Defines the position of the drawer.
     *
     * @demo
     * <cxl-drawer position="left" visible>
     *   <cxl-c pad16>
     *     <cxl-t h6>Left Drawer</cxl-t>
     *     <cxl-t>Left Drawer Content</cxl-t>
     *   </cxl-c>
     * </cxl-drawer>
     */
    position?: 'left' | 'right' | 'static';
    /**
     * A breakpoint or breakpoint key that determines when the drawer switches
     * to a full-screen modal behavior on smaller screens.
     */
    responsive?: BreakpointKey;
    /**
     * Controls whether the drawer acts as a permanent side panel
     */
    permanent: boolean;
}
