import { Component } from './component.js';
/**
 * The cxl-drop-target component provides a designated area for users to drag and drop content.
 * It displays different visual cues depending on whether the user is hovering over the drop zone or not.
 * Supports custom content through slots for both the hover and non-hover states.
 *
 * @beta
 *
 * @event change Triggered whenever the value attribute changes (after a successful drop).
 *
 * @demo
 * <cxl-drop-target>
 *   <cxl-c pad="16" color="primary" slot="over">OVER</cxl-c>
 *   <cxl-c pad="16" slot="notover">Drag And Drop Here</cxl-c>
 * </cxl-drop-target>
 */
export declare class DropTarget extends Component {
    /**
     * An array of DataTransferItem objects representing the currently dropped items.
     * This attribute is read-only and updates automatically upon successful drop events.
     */
    readonly value: DataTransferItem[];
}
