import { SurfaceColorValue } from './theme.js';
import { ButtonBase } from './button.js';
/**
 * The Fab component represents a floating action button (FAB) designed to highlight the primary action within a screen.
 * It's a circular, elevated button typically placed near the bottom corner of the screen to provide quick access to a critical function.
 *
 * Typical Uses:
 * - Initiating the main action of a screen (e.g., creating a new item, adding content).
 * - Triggering navigation to a new, related view.
 * - Providing access to contextual actions relevant to the current content.
 *
 * @demo
 * <cxl-fab title="Floating Action Button">&plus;</cxl-fab>
 */
export declare class Fab extends ButtonBase {
    /**
     * Controls whether the FAB is positioned fixed at the bottom corner.
     */
    fixed: boolean;
    /**
     * Sets the color of the button. This applies to both the button text and the ripple effect (if applicable).
     */
    color: SurfaceColorValue;
}
