import { Component } from './component.js';
import { LocaleName } from './locale.js';
/**
 * The Ck component provides a mechanism for displaying localized text.
 *
 * @beta
 * @demo
 */
export declare class Ck extends Component {
}
/**
 * The Locale component serves as a central element for managing localized text.
 * It acts as a bridge between your components and the content manager, a service
 * responsible for handling active locale and retrieving localized text.
 *
 * Sets the active locale for the content manager based on an attribute value or the
 * user's browser language. This ensures that child components inherit the appropriate
 * locale and display localized text accordingly.
 *
 * @beta
 */
export declare class Locale extends Component {
    /**
     * An attribute of type LocaleName that enables you to specify the desired locale
     * for the component and its descendants.
     *
     * If not provided, the component follows a fallback mechanism:
     * - The component checks for the presence of the locale attribute and uses its value if set.
     * - In the absence of a component-level locale, it attempts to retrieve the language preference
     *   from the user's browser using navigator?.language as LocaleName.
     * - If neither of the above methods provide a locale, it defaults to 'default' to ensure the
     *   application displays content in a fallback language.
     *
     */
    locale?: LocaleName;
}
