import { TextInputBase } from './input.js';
/**
 * The `<cxl-input-currency>` component leverages the Intl.NumberFormat API
 * to format user input according to specific currency locales.
 *
 * @demo
<cxl-field>
    <cxl-label>Currency Input</cxl-label>
    <cxl-input-currency value="20.05"></cxl-input-currency>
</cxl-field>
 * @beta
 */
export declare class InputCurrency extends TextInputBase {
    inputEl: HTMLInputElement;
    /**
     * The current currency value as a number.
     */
    value: number | undefined;
    /**
     * An optional string attribute that allows you to override the browser's default locale.
     */
    locale?: string;
    /**
     * An optional property that allows you to customize the formatting beyond the default currency style.
     * You can provide an object following the `Intl.NumberFormatOptions` specification.
     */
    format?: Intl.NumberFormatOptions;
    /**
     * Setting `hidesymbol` to `true` hides the currency symbol from the formatted output.
     * @demo
     * <cxl-input-currency hidesymbol value="20.05"></cxl-input-currency>
     */
    hidesymbol: boolean;
}
