import { Component } from './component.js';
import { SelectInput, SelectMenuBase } from './select.js';
import { Option } from './option.js';
export declare class MultiSelectOption extends Component {
}
/**
 * The Multiselect component provides a dropdown menu for selecting multiple options from
 * a list. It's typically used within a form context.
 *
 * @example
 * <cxl-field>
 *   <cxl-label>Multi Select Box with label</cxl-label>
 *   <cxl-select-input></cxl-select-input>
 *   <cxl-multiselect>
 *     <cxl-option selected value="1">Option 1</cxl-option>
 *     <cxl-option selected value="2">Option 2</cxl-option>
 *     <cxl-option value="3">Option 3</cxl-option>
 *   </cxl-multiselect>
 *   <cxl-input-placeholder>(Select an Option)</cxl-input-placeholder>
 * </cxl-field>
 */
export declare class MultiSelect extends SelectMenuBase {
    /**
     *  A property referencing the component used to render each option within the dropdown list (MultiSelectOption in this case).
     */
    readonly optionView: typeof MultiSelectOption;
    /**
     * A Set containing the currently selected options.
     */
    readonly selected: Set<Option>;
    /**
     * This method updates the text displayed in the select input field based on the currently
     * selected options or the placeholder text if nothing is selected.
     */
    protected setInputLabel(input: SelectInput): void;
    /**
     * This method updates the selected state of an option (adding/removing it from the selected set)
     * and handles setting focus if the dropdown is visible.
     */
    protected setSelected(option: Option): void;
    /**
     * This method sets the currently focused option within the dropdown and clears any previous focus.
     */
    setFocusedOption(option: Option): void;
    /**
     * This method clears the focused option within the dropdown.
     */
    protected clearFocusedOption(): void;
}
