import { Component } from './component.js';
import { Drawer } from './drawer.js';
import { Toggle } from './toggle.js';
/**
 * The Navbar component represents a navigation drawer that provides access to various destinations within
 * an application. It typically appears along the side of the screen and can be opened/closed using a toggle button.
 *
 * @demo
 * <cxl-appbar>
 *   <cxl-navbar></cxl-navbar>
 *   <cxl-appbar-title>Appbar with Navbar</cxl-appbar-title>
 * </cxl-appbar>
 */
export declare class Navbar extends Component {
    /**
     * A boolean attribute specifying whether the navbar should be permanently displayed on the left side
     * of the screen for large screens (@large breakpoint).
     */
    permanent: boolean;
    readonly drawer?: Drawer;
}
/**
 * The NavbarToggle component represents a standalone navigation toggle button that can be used to
 * open or close a navigation drawer. It's typically placed within a toolbar or similar area.
 *
 * @beta
 * @demo
 * <cxl-toolbar>
 *   <cxl-navbar-toggle target="drawer"></cxl-navbar-toggle>
 * </cxl-toolbar>
 * <cxl-drawer id="drawer">Navbar</cxl-drawer>
 */
export declare class NavbarToggle extends Toggle {
}
/**
 * The NavbarSubtitle component provides a styled element for displaying a subtitle within a navigation bar.
 */
export declare class NavbarSubtitle extends Component {
}
