export interface NavigationGridOptions {
    host: HTMLElement;
    goFirst(): Element | null;
    goFirstColumn(): Element | null;
    goLastColumn(): Element | null;
    goLast(): Element | null;
    goLeft(): Element | null;
    goRight(): Element | null;
    goUp(): Element | null;
    goDown(): Element | null;
    other?(key: string): Element | null;
}
/**
 * This function creates a NavigationGridOptions object based on the provided configuration options
 * like host element, selectors for focusable elements, starting element, and number of columns in the grid.
 */
export declare function navigationGridOptions({ host, selector, focusSelector, startSelector, columns, }: {
    host: HTMLElement;
    selector: string;
    startSelector: string;
    focusSelector: string;
    columns: number;
}): NavigationGridOptions;
/**
 * This function handles managing focus within the grid. It sets `tabIndex` to -1 for all
 * focusable elements to prevent them from being focused by tabbing.
 * It keeps track of the currently focused element. Whenever the children of the host element change
 * (due to DOM updates), it resets the `tabIndex` for all elements and sets it to 0 for the first
 * focusable element.
 * It also listens for `focusin` event on the host element to update the `focusedChild` whenever focus
 * moves within the grid using other methods.
 */
export declare function manageGridFocus(options: {
    host: HTMLElement;
    getFocusable: () => HTMLElement[];
}): import("./rx.js").Observable<never, "none">;
/**
 * This function creates an observable that listens to `keydown` events on the host element.
 * It uses the `handleListArrowKeys` function to handle the keyboard events and move focus within the grid.
 * It filters out events that don't result in a focus change (i.e., if the pressed key doesn't correspond
 * to a valid navigation direction).
 */
export declare function navigationGrid(options: NavigationGridOptions): import("./rx.js").Observable<Element | null, "none">;
