import { Component } from './component.js';
/**
 * The Navigation component provides generic navigation controls for iterating through a sequence with
 * a defined range. It typically consists of buttons for going to the first, previous, next, and last item.
 *
 * @beta
 * @demo
 * <cxl-navigation max="50"></cxl-navigation>
 */
export declare class Navigation extends Component {
    /**
     * A numeric attribute specifying the minimum allowed value in the sequence
     */
    min: number;
    /**
     * A numeric attribute specifying the maximum allowed value in the sequence
     */
    max: number;
    /**
     * A numeric attribute representing the current position within the sequence
     */
    value: number;
    /**
     * A boolean attribute that controls the visibility of the first and last page buttons.
     * @demo
     * <cxl-navigation hidefirstlast max="50"></cxl-navigation>
     */
    hidefirstlast: boolean;
    /**
     * Sets the value to the minimum (min) position.
     */
    goFirst(): void;
    /** Increments the value by 1 if it's less than max. */
    goNext(): void;
    /** Decrements the value by 1 if it's greater than min. */
    goPrevious(): void;
    /** Sets the value to the maximum (max) position. */
    goLast(): void;
}
