import { Component } from './component.js';
/**
 * The Option component represents a single option within a dropdown menu or similar selectable list.
 * It provides features for managing the option's state (selected, focused, hidden) and rendering its content.
 */
export declare class Option extends Component {
    /** An attribute specifying the unique value associated with the option. */
    value: unknown;
    /** An attribute referencing another component class that defines how the option should be rendered visually. */
    view?: typeof Component;
    /** A boolean style attribute indicating whether the option is currently selected. */
    selected: boolean;
    /** A boolean style attribute indicating whether the option should be hidden. */
    hidden: boolean;
    /** A boolean style attribute indicating whether the option is currently focused. */
    focused: boolean;
    /** A property holding a reference to the underlying HTML element used to render the option (populated by the component). */
    readonly rendered?: HTMLElement;
}
