import { Component } from './component.js';
export declare function attachRipple<T extends HTMLElement>(hostEl: T, ev: MouseEvent | KeyboardEvent): void;
/**
 * Attaches a ripple element (cxl-ripple) to a host element upon a mouse or keyboard event.
 * Positions the ripple element based on the event coordinates.
 */
export declare function ripple(element: HTMLElement & {
    disabled?: boolean;
}): import("./rx.js").Observable<MouseEvent, "none">;
/**
 * The Ripple component adds a visual ripple effect to clickable elements,
 * enhancing user experience by providing clear feedback upon interaction.
 */
export declare class Ripple extends Component {
    /** Controls the horizontal position of the ripple effect's origin */
    x: number;
    /** Controls the vertical position of the ripple effect's origin. */
    y: number;
    /** Determines the size of the ripple wave.*/
    radius: number;
}
/**
 * A container element for clickable elements with ripple effects.
 * Handles ripple attachment using the ripple function. Provides basic styling for containing ripple elements.
 *
 * @example
 * <cxl-ripple-container style="border:1px solid #000;padding:16px" ><cxl-t font="h3" center>Click Me</cxl-t></cxl-ripple-container>
 */
export declare class RippleContainer extends Component {
}
