import { Component } from './component.js';
import type { Option } from './option.js';
/**
 * This component represents a group of selectable elements.
 * It allows users to choose one option at a time from a set of choices.
 * Children components must have a `selected` property.
 *
 * @beta
 * @demo
 * <cxl-selectable-group aria-label="Chip Group">
 *   <cxl-selectable-button selected><cxl-icon title="Align Left"  name="format_align_left"></cxl-icon></cxl-selectable-button>
 *   <cxl-selectable-button><cxl-icon title="Align Center" name="format_align_center"></cxl-icon></cxl-selectable-button>
 *   <cxl-selectable-button><cxl-icon title="Align Right" name="format_align_right"></cxl-icon></cxl-selectable-button>
 * </cxl-selectable-group>
 */
export declare class SelectableGroup extends Component {
    /**
     * The currently selected value of the chip group. Can be any type.
     */
    value: unknown;
    /**
     * The currently selected chip within the chip group.
     */
    selected: Option | undefined;
    /**
     * A set containing all the options available in the chip group.
     */
    readonly options: Set<Option>;
}
