import { Component } from './component.js';
import { IconButton } from './icon-button.js';
/**
 * The Theme component dynamically loads theme styles based on the `theme` attribute value.
 * The component reacts to changes in the theme attribute and reloads the styles accordingly.
 */
export declare class Theme extends Component {
    /**
     * This attribute specifies the name of the theme to be loaded.
     * When this attribute changes, the component triggers a style reload.
     */
    theme: string;
    /**
     * This attribute specifies a key to be used for storing the user's theme preference in local storage. If provided, the component will attempt to retrieve the stored preference on initialization. It will also update local storage whenever the user changes the theme.
     */
    persistkey: string;
}
/**
 * The ThemeToggle component provides a mechanism for users to switch between different themes within your application.
 */
export declare class ThemeToggle extends Component {
    /**
     * This attribute specifies the name of the theme activated when the toggle button is off.
     * If empty it will use the default theme.
     */
    theme: string;
    /**
     * This attribute specifies the name of the theme activated when the toggle button is on.
     */
    darktheme: string;
    /**
     * This attribute controls the initial state of the toggle. Set value to true to make the toggle button selected by default.
     */
    value: boolean;
    /**
     * This attribute determines whether the component should use the user's preferred color scheme from the browser settings. Set usepreferred to true to enable this behavior.
     */
    usepreferred: boolean;
    /**
     * This attribute specifies a key to be used for storing the user's theme preference in local storage. If provided, the component will attempt to retrieve the stored preference on initialization and set the toggle state accordingly. It will also update local storage whenever the user changes the theme using the toggle button.
     *
     */
    persistkey: string;
}
/**
 * The ThemeToggleIcon component offers a visual toggle for users to switch between themes. It renders an icon button that reflects the current theme state
 *
 * - Renders an icon button with the appropriate icon based on the toggle state.
 * - Manages theme toggling functionality, inheriting behavior from ThemeToggleBehavior.
 * - Updates the displayed icon when the toggle state changes.
 *
 * @demo
 * <cxl-theme-toggle-icon aria-label="Toggle theme"></cxl-theme-toggle-icon>
 */
export declare class ThemeToggleIcon extends IconButton {
    /**
     * This attribute specifies the name of the theme activated when the toggle button is off.
     * If empty it will use the default theme.
     */
    theme: string;
    /**
     * This attribute specifies the name of the theme activated when the toggle button is on.
     */
    darktheme: string;
    /**
     * This attribute controls the initial state of the toggle. Set value to true to make the toggle button selected by default.
     */
    value: boolean;
    /**
     * This attribute determines whether the component should use the user's preferred color scheme from the browser settings. Set usepreferred to true to enable this behavior.
     */
    usepreferred: boolean;
    /**
     * This attribute specifies a key to be used for storing the user's theme preference in local storage. If provided, the component will attempt to retrieve the stored preference on initialization and set the toggle state accordingly. It will also update local storage whenever the user changes the theme using the toggle button.
     *
     */
    persistkey: string;
    /** Name of the icon to display when the toggle is active (default: "wb_sunny"). */
    iconon: string;
    /**  Name of the icon to display when the toggle is inactive (default: "dark_mode"). */
    iconoff: string;
}
