import { Styles as CssStyles, StyleDefinition, PartialTheme, Color, RGBA } from './css.js';
import type { Component } from './component.js';
type ArrayElement<ArrayType extends readonly unknown[]> = ArrayType extends readonly (infer ElementType)[] ? ElementType : never;
export interface SvgIconAttributes {
    className?: string;
    width?: number;
    height?: number;
    alt?: string;
}
export type StyleDef = StyleDefinition<UiTheme>;
export type UiTheme = typeof theme;
export type Styles = CssStyles<UiTheme>;
export type ThemeColor = keyof UiTheme['colors'];
export type SurfaceColorValue = ArrayElement<typeof surfaceColors> | 'inherit' | 'transparent';
export type AnimationKey = keyof UiTheme['animation'];
export type BaseColors = typeof baseColors;
export interface IconDef {
    id: string;
    icon(prop?: SvgIconAttributes): SVGSVGElement;
}
export declare const baseColors: {
    primary: RGBA;
    onPrimary: RGBA;
    secondary: RGBA;
    onSecondary: RGBA;
    surface: RGBA;
    onSurface: RGBA;
    background: RGBA;
    onBackground: RGBA;
};
export declare const onThemeChange: import("./rx.js").Reference<(PartialTheme & {
    css: string;
    name: string;
}) | undefined>;
export declare const theme: {
    animation: {
        none: undefined;
        flash: {
            kf: {
                opacity: number[];
            };
            options: {
                iterations: number;
                easing: string;
            };
        };
        spin: {
            kf: {
                rotate: string[];
            };
            options: {
                iterations: number;
                duration: number;
                easing: string;
            };
        };
        pulse: {
            kf: {
                rotate: string[];
            };
            options: {
                iterations: number;
                easing: string;
                duration: number;
            };
        };
        expand: {
            kf: {
                scale: number[];
            };
            options: {
                iterations: number;
                easing: string;
            };
        };
        zoomIn: {
            kf: {
                scale: number[];
            };
        };
        zoomOut: {
            kf: {
                scale: number[];
            };
        };
        fadeIn: {
            kf: {
                opacity: number;
            }[];
            options: {
                easing: string;
                fill: string;
            };
        };
        fadeOut: {
            kf: ({
                opacity: number;
                visibility?: undefined;
            } | {
                opacity: number;
                visibility: string;
            })[];
            options: {
                easing: string;
                fill: string;
            };
        };
        shakeX: {
            kf: {
                translate: (string | number)[];
            };
        };
        shakeY: {
            kf: {
                translate: (string | number)[];
            };
        };
        slideOutLeft: {
            kf: {
                translate: (string | number)[];
            };
        };
        slideInLeft: {
            kf: {
                translate: (string | number)[];
            };
        };
        slideOutRight: {
            kf: {
                translate: (string | number)[];
            };
        };
        slideInRight: {
            kf: {
                translate: (string | number)[];
            };
        };
        slideInUp: {
            kf: {
                translate: (string | number)[];
            };
        };
        slideInDown: {
            kf: {
                translate: (string | number)[];
            };
        };
        slideOutUp: {
            kf: {
                translate: (string | number)[];
            };
        };
        slideOutDown: {
            kf: {
                translate: (string | number)[];
            };
        };
        wait: {
            kf: {
                transform: string;
            }[];
            options: {
                duration: number;
                iterations: number;
                easing: string;
            };
        };
        focus: {
            kf: ({
                offset: number;
                filter: string;
            } | {
                filter: string;
                offset?: undefined;
            })[];
            options: {
                duration: number;
            };
        };
        spinnerstroke: {
            options: {
                duration: number;
                iterations: number;
                easing: string;
            };
            kf: {
                offset: number;
                strokeDashoffset: string;
                transform: string;
            }[];
        };
    };
    variables: {
        speed: string;
        font: string;
        fontMonospace: string;
        maskOpacity8: number;
        maskOpacity10: number;
        maskOpacity12: number;
        scrollbarWidth: string;
        scrollbarHeight: string;
        scrollbarForeground: string;
    };
    typography: {
        default: {
            fontWeight: number;
            fontFamily: string;
            fontSize: string;
            letterSpacing: string;
        };
        caption: {
            fontSize: string;
            letterSpacing: string;
        };
        h1: {
            fontWeight: number;
            fontSize: string;
            letterSpacing: string;
        };
        h2: {
            fontWeight: number;
            fontSize: string;
            letterSpacing: string;
        };
        h3: {
            fontSize: string;
        };
        h4: {
            fontSize: string;
            letterSpacing: string;
        };
        h5: {
            fontSize: string;
        };
        h6: {
            fontSize: string;
            fontWeight: number;
            letterSpacing: string;
        };
        body2: {
            fontSize: string;
            letterSpacing: string;
        };
        subtitle: {
            letterSpacing: string;
        };
        subtitle2: {
            fontSize: string;
            fontWeight: number;
            letterSpacing: string;
        };
        button: {
            fontSize: string;
            fontWeight: number;
            letterSpacing: string;
            textTransform: string;
        };
        code: {
            fontFamily: string;
            fontSize: string;
        };
    };
    colors: {
        error: RGBA;
        errorOnPrimary: RGBA;
        onError: RGBA;
        warning: RGBA;
        onWarning: RGBA;
        success: RGBA;
        onSuccess: RGBA;
        darkGray: RGBA;
        onDarkGray: RGBA;
        fieldMask: string;
        primaryLight: RGBA;
        onPrimaryLight: RGBA;
        secondaryLight: RGBA;
        onSecondaryLight: RGBA;
        headerText: RGBA;
        onSurface8: RGBA;
        onSurface12: RGBA;
        divider: RGBA;
        shadow: RGBA;
        primary: RGBA;
        onPrimary: RGBA;
        secondary: RGBA;
        onSecondary: RGBA;
        surface: RGBA;
        onSurface: RGBA;
        background: RGBA;
        onBackground: RGBA;
    };
    imports: string[] | undefined;
    globalCss: string;
    global: {
        readonly '@a': {
            readonly color: "primary";
        };
        readonly 'cxl-selection,::selection': {
            readonly backgroundColor: "secondary";
            readonly color: "onSecondary";
        };
        readonly '*': {
            readonly boxSizing: "border-box";
            readonly transition: "opacity var(--cxl-speed), transform var(--cxl-speed), box-shadow var(--cxl-speed), filter var(--cxl-speed), rotate var(--cxl-speed)";
        };
    };
    breakpoints: import("./css.js").Breakpoints;
    unit: import("./css.js").CSSUnit;
};
export declare const FontValues: string[];
export declare const applyTheme: (container?: HTMLHeadElement) => void, baseColor: (name: "error" | "background" | "errorOnPrimary" | "onError" | "warning" | "onWarning" | "success" | "onSuccess" | "darkGray" | "onDarkGray" | "fieldMask" | "primaryLight" | "onPrimaryLight" | "secondaryLight" | "onSecondaryLight" | "headerText" | "onSurface8" | "onSurface12" | "divider" | "shadow" | "primary" | "secondary" | "onSecondary" | "onSurface" | "onPrimary" | "surface" | "onBackground") => string, render: (styles: CssStyles<{
    animation: {
        none: undefined;
        flash: {
            kf: {
                opacity: number[];
            };
            options: {
                iterations: number;
                easing: string;
            };
        };
        spin: {
            kf: {
                rotate: string[];
            };
            options: {
                iterations: number;
                duration: number;
                easing: string;
            };
        };
        pulse: {
            kf: {
                rotate: string[];
            };
            options: {
                iterations: number;
                easing: string;
                duration: number;
            };
        };
        expand: {
            kf: {
                scale: number[];
            };
            options: {
                iterations: number;
                easing: string;
            };
        };
        zoomIn: {
            kf: {
                scale: number[];
            };
        };
        zoomOut: {
            kf: {
                scale: number[];
            };
        };
        fadeIn: {
            kf: {
                opacity: number;
            }[];
            options: {
                easing: string;
                fill: string;
            };
        };
        fadeOut: {
            kf: ({
                opacity: number;
                visibility?: undefined;
            } | {
                opacity: number;
                visibility: string;
            })[];
            options: {
                easing: string;
                fill: string;
            };
        };
        shakeX: {
            kf: {
                translate: (string | number)[];
            };
        };
        shakeY: {
            kf: {
                translate: (string | number)[];
            };
        };
        slideOutLeft: {
            kf: {
                translate: (string | number)[];
            };
        };
        slideInLeft: {
            kf: {
                translate: (string | number)[];
            };
        };
        slideOutRight: {
            kf: {
                translate: (string | number)[];
            };
        };
        slideInRight: {
            kf: {
                translate: (string | number)[];
            };
        };
        slideInUp: {
            kf: {
                translate: (string | number)[];
            };
        };
        slideInDown: {
            kf: {
                translate: (string | number)[];
            };
        };
        slideOutUp: {
            kf: {
                translate: (string | number)[];
            };
        };
        slideOutDown: {
            kf: {
                translate: (string | number)[];
            };
        };
        wait: {
            kf: {
                transform: string;
            }[];
            options: {
                duration: number;
                iterations: number;
                easing: string;
            };
        };
        focus: {
            kf: ({
                offset: number;
                filter: string;
            } | {
                filter: string;
                offset?: undefined;
            })[];
            options: {
                duration: number;
            };
        };
        spinnerstroke: {
            options: {
                duration: number;
                iterations: number;
                easing: string;
            };
            kf: {
                offset: number;
                strokeDashoffset: string;
                transform: string;
            }[];
        };
    };
    variables: {
        speed: string;
        font: string;
        fontMonospace: string;
        maskOpacity8: number;
        maskOpacity10: number;
        maskOpacity12: number;
        scrollbarWidth: string;
        scrollbarHeight: string;
        scrollbarForeground: string;
    };
    typography: {
        default: {
            fontWeight: number;
            fontFamily: string;
            fontSize: string;
            letterSpacing: string;
        };
        caption: {
            fontSize: string;
            letterSpacing: string;
        };
        h1: {
            fontWeight: number;
            fontSize: string;
            letterSpacing: string;
        };
        h2: {
            fontWeight: number;
            fontSize: string;
            letterSpacing: string;
        };
        h3: {
            fontSize: string;
        };
        h4: {
            fontSize: string;
            letterSpacing: string;
        };
        h5: {
            fontSize: string;
        };
        h6: {
            fontSize: string;
            fontWeight: number;
            letterSpacing: string;
        };
        body2: {
            fontSize: string;
            letterSpacing: string;
        };
        subtitle: {
            letterSpacing: string;
        };
        subtitle2: {
            fontSize: string;
            fontWeight: number;
            letterSpacing: string;
        };
        button: {
            fontSize: string;
            fontWeight: number;
            letterSpacing: string;
            textTransform: string;
        };
        code: {
            fontFamily: string;
            fontSize: string;
        };
    };
    colors: {
        error: RGBA;
        errorOnPrimary: RGBA;
        onError: RGBA;
        warning: RGBA;
        onWarning: RGBA;
        success: RGBA;
        onSuccess: RGBA;
        darkGray: RGBA;
        onDarkGray: RGBA;
        fieldMask: string;
        primaryLight: RGBA;
        onPrimaryLight: RGBA;
        secondaryLight: RGBA;
        onSecondaryLight: RGBA;
        headerText: RGBA;
        onSurface8: RGBA;
        onSurface12: RGBA;
        divider: RGBA;
        shadow: RGBA;
        primary: RGBA;
        onPrimary: RGBA;
        secondary: RGBA;
        onSecondary: RGBA;
        surface: RGBA;
        onSurface: RGBA;
        background: RGBA;
        onBackground: RGBA;
    };
    imports: string[] | undefined;
    globalCss: string;
    global: {
        readonly '@a': {
            readonly color: "primary";
        };
        readonly 'cxl-selection,::selection': {
            readonly backgroundColor: "secondary";
            readonly color: "onSecondary";
        };
        readonly '*': {
            readonly boxSizing: "border-box";
            readonly transition: "opacity var(--cxl-speed), transform var(--cxl-speed), box-shadow var(--cxl-speed), filter var(--cxl-speed), rotate var(--cxl-speed)";
        };
    };
    breakpoints: import("./css.js").Breakpoints;
    unit: import("./css.js").CSSUnit;
}>, baseSelector?: string) => string, style: (styles: CssStyles<{
    animation: {
        none: undefined;
        flash: {
            kf: {
                opacity: number[];
            };
            options: {
                iterations: number;
                easing: string;
            };
        };
        spin: {
            kf: {
                rotate: string[];
            };
            options: {
                iterations: number;
                duration: number;
                easing: string;
            };
        };
        pulse: {
            kf: {
                rotate: string[];
            };
            options: {
                iterations: number;
                easing: string;
                duration: number;
            };
        };
        expand: {
            kf: {
                scale: number[];
            };
            options: {
                iterations: number;
                easing: string;
            };
        };
        zoomIn: {
            kf: {
                scale: number[];
            };
        };
        zoomOut: {
            kf: {
                scale: number[];
            };
        };
        fadeIn: {
            kf: {
                opacity: number;
            }[];
            options: {
                easing: string;
                fill: string;
            };
        };
        fadeOut: {
            kf: ({
                opacity: number;
                visibility?: undefined;
            } | {
                opacity: number;
                visibility: string;
            })[];
            options: {
                easing: string;
                fill: string;
            };
        };
        shakeX: {
            kf: {
                translate: (string | number)[];
            };
        };
        shakeY: {
            kf: {
                translate: (string | number)[];
            };
        };
        slideOutLeft: {
            kf: {
                translate: (string | number)[];
            };
        };
        slideInLeft: {
            kf: {
                translate: (string | number)[];
            };
        };
        slideOutRight: {
            kf: {
                translate: (string | number)[];
            };
        };
        slideInRight: {
            kf: {
                translate: (string | number)[];
            };
        };
        slideInUp: {
            kf: {
                translate: (string | number)[];
            };
        };
        slideInDown: {
            kf: {
                translate: (string | number)[];
            };
        };
        slideOutUp: {
            kf: {
                translate: (string | number)[];
            };
        };
        slideOutDown: {
            kf: {
                translate: (string | number)[];
            };
        };
        wait: {
            kf: {
                transform: string;
            }[];
            options: {
                duration: number;
                iterations: number;
                easing: string;
            };
        };
        focus: {
            kf: ({
                offset: number;
                filter: string;
            } | {
                filter: string;
                offset?: undefined;
            })[];
            options: {
                duration: number;
            };
        };
        spinnerstroke: {
            options: {
                duration: number;
                iterations: number;
                easing: string;
            };
            kf: {
                offset: number;
                strokeDashoffset: string;
                transform: string;
            }[];
        };
    };
    variables: {
        speed: string;
        font: string;
        fontMonospace: string;
        maskOpacity8: number;
        maskOpacity10: number;
        maskOpacity12: number;
        scrollbarWidth: string;
        scrollbarHeight: string;
        scrollbarForeground: string;
    };
    typography: {
        default: {
            fontWeight: number;
            fontFamily: string;
            fontSize: string;
            letterSpacing: string;
        };
        caption: {
            fontSize: string;
            letterSpacing: string;
        };
        h1: {
            fontWeight: number;
            fontSize: string;
            letterSpacing: string;
        };
        h2: {
            fontWeight: number;
            fontSize: string;
            letterSpacing: string;
        };
        h3: {
            fontSize: string;
        };
        h4: {
            fontSize: string;
            letterSpacing: string;
        };
        h5: {
            fontSize: string;
        };
        h6: {
            fontSize: string;
            fontWeight: number;
            letterSpacing: string;
        };
        body2: {
            fontSize: string;
            letterSpacing: string;
        };
        subtitle: {
            letterSpacing: string;
        };
        subtitle2: {
            fontSize: string;
            fontWeight: number;
            letterSpacing: string;
        };
        button: {
            fontSize: string;
            fontWeight: number;
            letterSpacing: string;
            textTransform: string;
        };
        code: {
            fontFamily: string;
            fontSize: string;
        };
    };
    colors: {
        error: RGBA;
        errorOnPrimary: RGBA;
        onError: RGBA;
        warning: RGBA;
        onWarning: RGBA;
        success: RGBA;
        onSuccess: RGBA;
        darkGray: RGBA;
        onDarkGray: RGBA;
        fieldMask: string;
        primaryLight: RGBA;
        onPrimaryLight: RGBA;
        secondaryLight: RGBA;
        onSecondaryLight: RGBA;
        headerText: RGBA;
        onSurface8: RGBA;
        onSurface12: RGBA;
        divider: RGBA;
        shadow: RGBA;
        primary: RGBA;
        onPrimary: RGBA;
        secondary: RGBA;
        onSecondary: RGBA;
        surface: RGBA;
        onSurface: RGBA;
        background: RGBA;
        onBackground: RGBA;
    };
    imports: string[] | undefined;
    globalCss: string;
    global: {
        readonly '@a': {
            readonly color: "primary";
        };
        readonly 'cxl-selection,::selection': {
            readonly backgroundColor: "secondary";
            readonly color: "onSecondary";
        };
        readonly '*': {
            readonly boxSizing: "border-box";
            readonly transition: "opacity var(--cxl-speed), transform var(--cxl-speed), box-shadow var(--cxl-speed), filter var(--cxl-speed), rotate var(--cxl-speed)";
        };
    };
    breakpoints: import("./css.js").Breakpoints;
    unit: import("./css.js").CSSUnit;
}>, selector?: string) => () => HTMLStyleElement, rootStyles: HTMLStyleElement, variable: {
    <K extends "error" | "background" | "errorOnPrimary" | "onError" | "warning" | "onWarning" | "success" | "onSuccess" | "darkGray" | "onDarkGray" | "fieldMask" | "primaryLight" | "onPrimaryLight" | "secondaryLight" | "onSecondaryLight" | "headerText" | "onSurface8" | "onSurface12" | "divider" | "shadow" | "primary" | "secondary" | "onSecondary" | "onSurface" | "onPrimary" | "surface" | "onBackground">(name: K): import("./css.js").Variable<{
        error: RGBA;
        errorOnPrimary: RGBA;
        onError: RGBA;
        warning: RGBA;
        onWarning: RGBA;
        success: RGBA;
        onSuccess: RGBA;
        darkGray: RGBA;
        onDarkGray: RGBA;
        fieldMask: string;
        primaryLight: RGBA;
        onPrimaryLight: RGBA;
        secondaryLight: RGBA;
        onSecondaryLight: RGBA;
        headerText: RGBA;
        onSurface8: RGBA;
        onSurface12: RGBA;
        divider: RGBA;
        shadow: RGBA;
        primary: RGBA;
        onPrimary: RGBA;
        secondary: RGBA;
        onSecondary: RGBA;
        surface: RGBA;
        onSurface: RGBA;
        background: RGBA;
        onBackground: RGBA;
    }[K]>;
    <K extends "font" | "scrollbarWidth" | "speed" | "fontMonospace" | "maskOpacity8" | "maskOpacity10" | "maskOpacity12" | "scrollbarHeight" | "scrollbarForeground">(name: K): import("./css.js").Variable<{
        speed: string;
        font: string;
        fontMonospace: string;
        maskOpacity8: number;
        maskOpacity10: number;
        maskOpacity12: number;
        scrollbarWidth: string;
        scrollbarHeight: string;
        scrollbarForeground: string;
    }[K]>;
};
declare const globalCssSymbol: unique symbol;
declare global {
    interface Node {
        [globalCssSymbol]?: boolean;
    }
}
export type Spacing = ArrayElement<typeof SpacingValues>;
export declare const SpacingValues: readonly [0, 4, 8, 16, 24, 32, 48, 64];
export declare const FocusCircleStyle: () => HTMLStyleElement;
export declare function loadTheme(name: string, key: string): void;
export declare function spacingCss(fn: (val: Spacing) => Styles): Styles;
export declare function observeTheme(host: Component): import("./rx.js").Observable<(PartialTheme & {
    css: string;
    name: string;
}) | undefined, "none">;
export declare function css(styles: Styles): (host: Component) => HTMLStyleElement;
type DerivedColors = ReturnType<typeof getDerivedColors>;
declare function getDerivedColors(b: BaseColors): {
    error: RGBA;
    errorOnPrimary: RGBA;
    onError: RGBA;
    warning: RGBA;
    onWarning: RGBA;
    success: RGBA;
    onSuccess: RGBA;
    darkGray: RGBA;
    onDarkGray: RGBA;
    fieldMask: string;
    primaryLight: RGBA;
    onPrimaryLight: RGBA;
    secondaryLight: RGBA;
    onSecondaryLight: RGBA;
    headerText: RGBA;
    onSurface8: RGBA;
    onSurface12: RGBA;
    divider: RGBA;
    shadow: RGBA;
};
export declare function buildPalette(colors: BaseColors, derived?: Partial<DerivedColors>): {
    error: RGBA;
    errorOnPrimary: RGBA;
    onError: RGBA;
    warning: RGBA;
    onWarning: RGBA;
    success: RGBA;
    onSuccess: RGBA;
    darkGray: RGBA;
    onDarkGray: RGBA;
    fieldMask: string;
    primaryLight: RGBA;
    onPrimaryLight: RGBA;
    secondaryLight: RGBA;
    onSecondaryLight: RGBA;
    headerText: RGBA;
    onSurface8: RGBA;
    onSurface12: RGBA;
    divider: RGBA;
    shadow: RGBA;
    primary: RGBA;
    onPrimary: RGBA;
    secondary: RGBA;
    onSecondary: RGBA;
    surface: RGBA;
    onSurface: RGBA;
    background: RGBA;
    onBackground: RGBA;
};
declare const surfaceColors: readonly ["background", "primary", "primaryLight", "secondary", "surface", "error", "success", "warning", "darkGray"];
export declare const SurfaceColorNames: string[];
export declare function applyColorFromString(color: string): string;
export declare const ColorStyles: Record<SurfaceColorValue, StyleDef>;
export declare const OutlineColorStyles: (prefix?: string) => Record<string, StyleDef>;
export declare function FlatColorStyles(prefix: string): Record<string, StyleDef>;
export type MaskType = keyof typeof mask;
declare const mask: {
    black8: RGBA;
    black12: RGBA;
};
export declare function bgMask(backgroundColor: Color<UiTheme>, maskType: MaskType): {
    backgroundColor: Color<{
        animation: {
            none: undefined;
            flash: {
                kf: {
                    opacity: number[];
                };
                options: {
                    iterations: number;
                    easing: string;
                };
            };
            spin: {
                kf: {
                    rotate: string[];
                };
                options: {
                    iterations: number;
                    duration: number;
                    easing: string;
                };
            };
            pulse: {
                kf: {
                    rotate: string[];
                };
                options: {
                    iterations: number;
                    easing: string;
                    duration: number;
                };
            };
            expand: {
                kf: {
                    scale: number[];
                };
                options: {
                    iterations: number;
                    easing: string;
                };
            };
            zoomIn: {
                kf: {
                    scale: number[];
                };
            };
            zoomOut: {
                kf: {
                    scale: number[];
                };
            };
            fadeIn: {
                kf: {
                    opacity: number;
                }[];
                options: {
                    easing: string;
                    fill: string;
                };
            };
            fadeOut: {
                kf: ({
                    opacity: number;
                    visibility?: undefined;
                } | {
                    opacity: number;
                    visibility: string;
                })[];
                options: {
                    easing: string;
                    fill: string;
                };
            };
            shakeX: {
                kf: {
                    translate: (string | number)[];
                };
            };
            shakeY: {
                kf: {
                    translate: (string | number)[];
                };
            };
            slideOutLeft: {
                kf: {
                    translate: (string | number)[];
                };
            };
            slideInLeft: {
                kf: {
                    translate: (string | number)[];
                };
            };
            slideOutRight: {
                kf: {
                    translate: (string | number)[];
                };
            };
            slideInRight: {
                kf: {
                    translate: (string | number)[];
                };
            };
            slideInUp: {
                kf: {
                    translate: (string | number)[];
                };
            };
            slideInDown: {
                kf: {
                    translate: (string | number)[];
                };
            };
            slideOutUp: {
                kf: {
                    translate: (string | number)[];
                };
            };
            slideOutDown: {
                kf: {
                    translate: (string | number)[];
                };
            };
            wait: {
                kf: {
                    transform: string;
                }[];
                options: {
                    duration: number;
                    iterations: number;
                    easing: string;
                };
            };
            focus: {
                kf: ({
                    offset: number;
                    filter: string;
                } | {
                    filter: string;
                    offset?: undefined;
                })[];
                options: {
                    duration: number;
                };
            };
            spinnerstroke: {
                options: {
                    duration: number;
                    iterations: number;
                    easing: string;
                };
                kf: {
                    offset: number;
                    strokeDashoffset: string;
                    transform: string;
                }[];
            };
        };
        variables: {
            speed: string;
            font: string;
            fontMonospace: string;
            maskOpacity8: number;
            maskOpacity10: number;
            maskOpacity12: number;
            scrollbarWidth: string;
            scrollbarHeight: string;
            scrollbarForeground: string;
        };
        typography: {
            default: {
                fontWeight: number;
                fontFamily: string;
                fontSize: string;
                letterSpacing: string;
            };
            caption: {
                fontSize: string;
                letterSpacing: string;
            };
            h1: {
                fontWeight: number;
                fontSize: string;
                letterSpacing: string;
            };
            h2: {
                fontWeight: number;
                fontSize: string;
                letterSpacing: string;
            };
            h3: {
                fontSize: string;
            };
            h4: {
                fontSize: string;
                letterSpacing: string;
            };
            h5: {
                fontSize: string;
            };
            h6: {
                fontSize: string;
                fontWeight: number;
                letterSpacing: string;
            };
            body2: {
                fontSize: string;
                letterSpacing: string;
            };
            subtitle: {
                letterSpacing: string;
            };
            subtitle2: {
                fontSize: string;
                fontWeight: number;
                letterSpacing: string;
            };
            button: {
                fontSize: string;
                fontWeight: number;
                letterSpacing: string;
                textTransform: string;
            };
            code: {
                fontFamily: string;
                fontSize: string;
            };
        };
        colors: {
            error: RGBA;
            errorOnPrimary: RGBA;
            onError: RGBA;
            warning: RGBA;
            onWarning: RGBA;
            success: RGBA;
            onSuccess: RGBA;
            darkGray: RGBA;
            onDarkGray: RGBA;
            fieldMask: string;
            primaryLight: RGBA;
            onPrimaryLight: RGBA;
            secondaryLight: RGBA;
            onSecondaryLight: RGBA;
            headerText: RGBA;
            onSurface8: RGBA;
            onSurface12: RGBA;
            divider: RGBA;
            shadow: RGBA;
            primary: RGBA;
            onPrimary: RGBA;
            secondary: RGBA;
            onSecondary: RGBA;
            surface: RGBA;
            onSurface: RGBA;
            background: RGBA;
            onBackground: RGBA;
        };
        imports: string[] | undefined;
        globalCss: string;
        global: {
            readonly '@a': {
                readonly color: "primary";
            };
            readonly 'cxl-selection,::selection': {
                readonly backgroundColor: "secondary";
                readonly color: "onSecondary";
            };
            readonly '*': {
                readonly boxSizing: "border-box";
                readonly transition: "opacity var(--cxl-speed), transform var(--cxl-speed), box-shadow var(--cxl-speed), filter var(--cxl-speed), rotate var(--cxl-speed)";
            };
        };
        breakpoints: import("./css.js").Breakpoints;
        unit: import("./css.js").CSSUnit;
    }>;
    backgroundImage: string;
};
export declare const DisabledStyles: {
    cursor: string;
    filter: string;
    opacity: number;
    pointerEvents: string;
};
export declare const StateStyles: {
    $focus: {
        outline: number;
    };
    $disabled: {
        cursor: string;
        filter: string;
        opacity: number;
        pointerEvents: string;
    };
};
export declare function scrollbarStyles(prefix?: string): {
    [x: string]: {
        width: string;
        height: string;
        background?: undefined;
    } | {
        background: string;
        width?: undefined;
        height?: undefined;
    };
};
export declare function delayTheme(): void;
export declare function buildIconFactoryCdn(getUrl: (id: string, width?: number) => string): (id: string, width?: number) => Node;
/**
 * By default we use the material icons CDN to retrieve icon svg files.
 */
export declare const iconFactoryCdn: (id: string, width?: number) => Node;
export declare function registerDefaultIconFactory(fn: (id: string) => Node): void;
export declare function registerIcon(icon: IconDef): void;
export declare function getColorStyles(color: SurfaceColorValue): {
    color: string;
    backgroundColor: string;
};
export declare function getIcon(id: string, prop?: SvgIconAttributes): SVGSVGElement;
export {};
